@@ -4,36 +4,36 @@
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #pragma GCC diagnostic ignored "-Wstrict-aliasing"
-#ifdef __cplusplus
-  #pragma GCC diagnostic ignored "-Wregister"
-#endif
 
 #ifdef STM32F0xx
   #include "stm32f0xx_ll_comp.h"
-#elif STM32F3xx
+#endif
+#ifdef STM32F3xx
   #include "stm32f3xx_ll_comp.h"
-#elif STM32G0xx
+#endif
+#ifdef STM32G0xx
   #include "stm32g0xx_ll_comp.h"
-#elif STM32G4xx
+#endif
+#ifdef STM32G4xx
   #include "stm32g4xx_ll_comp.h"
-#elif STM32H5xx
-  #include "stm32h5xx_ll_comp.h"
-#elif STM32H7xx
+#endif
+#ifdef STM32H7xx
   #include "stm32h7xx_ll_comp.h"
-#elif STM32L0xx
+#endif
+#ifdef STM32L0xx
   #include "stm32l0xx_ll_comp.h"
-#elif STM32L1xx
+#endif
+#ifdef STM32L1xx
   #include "stm32l1xx_ll_comp.h"
-#elif STM32L4xx
+#endif
+#ifdef STM32L4xx
   #include "stm32l4xx_ll_comp.h"
-#elif STM32L5xx
+#endif
+#ifdef STM32L5xx
   #include "stm32l5xx_ll_comp.h"
-#elif STM32U5xx
-  #include "stm32u5xx_ll_comp.h"
-#elif STM32WBxx
+#endif
+#ifdef STM32WBxx
   #include "stm32wbxx_ll_comp.h"
-#elif STM32WLxx
-  #include "stm32wlxx_ll_comp.h"
 #endif
 #pragma GCC diagnostic pop
 #endif /* _STM32YYXX_LL_COMP_H_ */
