@@ -4,18 +4,12 @@
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #pragma GCC diagnostic ignored "-Wstrict-aliasing"
-#ifdef __cplusplus
-  #pragma GCC diagnostic ignored "-Wregister"
-#endif
 
 #ifdef STM32G4xx
   #include "stm32g4xx_ll_cordic.h"
-#elif STM32H5xx
-  #include "stm32h5xx_ll_cordic.h"
-#elif STM32H7xx
+#endif
+#ifdef STM32H7xx
   #include "stm32h7xx_ll_cordic.h"
-#elif STM32U5xx
-  #include "stm32u5xx_ll_cordic.h"
 #endif
 #pragma GCC diagnostic pop
 #endif /* _STM32YYXX_LL_CORDIC_H_ */
