@@ -4,13 +4,11 @@
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wunused-parameter"
 #pragma GCC diagnostic ignored "-Wstrict-aliasing"
-#ifdef __cplusplus
-  #pragma GCC diagnostic ignored "-Wregister"
-#endif
 
 #ifdef STM32H7xx
   #include "stm32h7xx_ll_delayblock.h"
-#elif STM32MP1xx
+#endif
+#ifdef STM32MP1xx
   #include "stm32mp1xx_ll_delayblock.h"
 #endif
 #pragma GCC diagnostic pop
