@@ -2,11 +2,7 @@
 #define _STM32_DEF_BUILD_
 
 #if !defined(CMSIS_STARTUP_FILE) && !defined(CUSTOM_STARTUP_FILE)
-  #if defined(STM32C011xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32c011xx.s"
-  #elif defined(STM32C031xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32c031xx.s"
-  #elif defined(STM32F030x6)
+  #if defined(STM32F030x6)
     #define CMSIS_STARTUP_FILE "startup_stm32f030x6.s"
   #elif defined(STM32F030x8)
     #define CMSIS_STARTUP_FILE "startup_stm32f030x8.s"
@@ -182,24 +178,12 @@
     #define CMSIS_STARTUP_FILE "startup_stm32g031xx.s"
   #elif defined(STM32G041xx)
     #define CMSIS_STARTUP_FILE "startup_stm32g041xx.s"
-  #elif defined(STM32G050xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g050xx.s"
-  #elif defined(STM32G051xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g051xx.s"
-  #elif defined(STM32G061xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g061xx.s"
   #elif defined(STM32G070xx)
     #define CMSIS_STARTUP_FILE "startup_stm32g070xx.s"
   #elif defined(STM32G071xx)
     #define CMSIS_STARTUP_FILE "startup_stm32g071xx.s"
   #elif defined(STM32G081xx)
     #define CMSIS_STARTUP_FILE "startup_stm32g081xx.s"
-  #elif defined(STM32G0B0xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g0b0xx.s"
-  #elif defined(STM32G0B1xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g0b1xx.s"
-  #elif defined(STM32G0C1xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32g0c1xx.s"
   #elif defined(STM32G431xx)
     #define CMSIS_STARTUP_FILE "startup_stm32g431xx.s"
   #elif defined(STM32G441xx)
@@ -220,14 +204,6 @@
     #define CMSIS_STARTUP_FILE "startup_stm32g4a1xx.s"
   #elif defined(STM32GBK1CB)
     #define CMSIS_STARTUP_FILE "startup_stm32gbk1cb.s"
-  #elif defined(STM32H503xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32h503xx.s"
-  #elif defined(STM32H562xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32h562xx.s"
-  #elif defined(STM32H563xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32h563xx.s"
-  #elif defined(STM32H573xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32h573xx.s"
   #elif defined(STM32H723xx)
     #define CMSIS_STARTUP_FILE "startup_stm32h723xx.s"
   #elif defined(STM32H725xx)
@@ -244,12 +220,8 @@
     #define CMSIS_STARTUP_FILE "startup_stm32h742xx.s"
   #elif defined(STM32H743xx)
     #define CMSIS_STARTUP_FILE "startup_stm32h743xx.s"
-  #elif defined(STM32H745xG)
-    #define CMSIS_STARTUP_FILE "startup_stm32h745xg.s"
   #elif defined(STM32H745xx)
     #define CMSIS_STARTUP_FILE "startup_stm32h745xx.s"
-  #elif defined(STM32H747xG)
-    #define CMSIS_STARTUP_FILE "startup_stm32h747xg.s"
   #elif defined(STM32H747xx)
     #define CMSIS_STARTUP_FILE "startup_stm32h747xx.s"
   #elif defined(STM32H750xx)
@@ -409,7 +381,7 @@
   #elif defined(STM32L562xx)
     #define CMSIS_STARTUP_FILE "startup_stm32l562xx.s"
   #elif defined(STM32MP151Axx)
-    #define CMSIS_STARTUP_FILE "startup_stm32mp151axx_cm4.s"
+    #define CMSIS_STARTUP_FILE "startup_stm32mp151axx_cm4 .s"
   #elif defined(STM32MP151Cxx)
     #define CMSIS_STARTUP_FILE "startup_stm32mp151cxx_cm4.s"
   #elif defined(STM32MP153Axx)
@@ -422,36 +394,10 @@
     #define CMSIS_STARTUP_FILE "startup_stm32mp157cxx_cm4.s"
   #elif defined(STM32MP15xx)
     #define CMSIS_STARTUP_FILE "startup_stm32mp15xx.s"
-  #elif defined(STM32U535xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u535xx.s"
-  #elif defined(STM32U545xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u545xx.s"
-  #elif defined(STM32U575xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u575xx.s"
-  #elif defined(STM32U585xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u585xx.s"
-  #elif defined(STM32U595xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u595xx.s"
-  #elif defined(STM32U599xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u599xx.s"
-  #elif defined(STM32U5A5xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5a5xx.s"
-  #elif defined(STM32U5A9xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5a9xx.s"
-  #elif defined(STM32U5F7xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5f7xx.s"
-  #elif defined(STM32U5F9xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5f9xx.s"
-  #elif defined(STM32U5G7xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5g7xx.s"
-  #elif defined(STM32U5G9xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32u5g9xx.s"
   #elif defined(STM32WB10xx)
     #define CMSIS_STARTUP_FILE "startup_stm32wb10xx_cm4.s"
   #elif defined(STM32WB15xx)
     #define CMSIS_STARTUP_FILE "startup_stm32wb15xx_cm4.s"
-  #elif defined(STM32WB1Mxx)
-    #define CMSIS_STARTUP_FILE "startup_stm32wb1mxx_cm4.s"
   #elif defined(STM32WB30xx)
     #define CMSIS_STARTUP_FILE "startup_stm32wb30xx_cm4.s"
   #elif defined(STM32WB35xx)
@@ -462,22 +408,6 @@
     #define CMSIS_STARTUP_FILE "startup_stm32wb55xx_cm4.s"
   #elif defined(STM32WB5Mxx)
     #define CMSIS_STARTUP_FILE "startup_stm32wb5mxx_cm4.s"
-  #elif defined(STM32WL54xx) && defined(USE_CM0PLUS_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl54xx_cm0plus.s"
-  #elif defined(STM32WL54xx) && defined(USE_CM4_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl54xx_cm4.s"
-  #elif defined(STM32WL55xx) && defined(USE_CM0PLUS_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl55xx_cm0plus.s"
-  #elif defined(STM32WL55xx) && defined(USE_CM4_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl55xx_cm4.s"
-  #elif defined(STM32WL5Mxx) && defined(USE_CM0PLUS_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl5mxx_cm0plus.s"
-  #elif defined(STM32WL5Mxx) && defined(USE_CM4_STARTUP_FILE)
-    #define CMSIS_STARTUP_FILE "startup_stm32wl5mxx_cm4.s"
-  #elif defined(STM32WLE4xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32wle4xx.s"
-  #elif defined(STM32WLE5xx)
-    #define CMSIS_STARTUP_FILE "startup_stm32wle5xx.s"
   #else
     #error UNKNOWN CHIP
   #endif
