@@ -51,24 +51,15 @@ PCD_HandleTypeDef g_hpcd;
 void HAL_PCD_MspInit(PCD_HandleTypeDef *hpcd)
 {
   const PinMap *map = NULL;
-
-#if defined(PIN_UCPD_TCPP)
-  /* Set TCPP default state: Type-C legacy */
-  pinMode(PIN_UCPD_TCPP, OUTPUT_OPEN_DRAIN);
-  digitalWriteFast(digitalPinToPinName(PIN_UCPD_TCPP), LOW);
-#endif
-#if defined(PWR_CR3_USB33DEN) || defined(PWR_USBSCR_USB33DEN)
-  HAL_PWREx_EnableUSBVoltageDetector();
-#endif
-#if defined(PWR_CR3_USB33RDY)
-  while (!LL_PWR_IsActiveFlag_USB());
-#elif defined(PWR_VMSR_USB33RDY)
-  while (!LL_PWR_IsActiveFlag_VDDUSB());
-#endif
-#if defined(PWR_CR2_USV) || defined(PWR_SVMCR_USV) || defined(PWR_USBSCR_USB33SV)
-  /* Enable VDDUSB */
+#if defined(PWR_CR2_USV)
+  /* Enable VDDUSB on Pwrctrl CR2 register*/
   HAL_PWREx_EnableVddUSB();
 #endif
+#ifdef STM32H7xx
+  if (!LL_PWR_IsActiveFlag_USB()) {
+    HAL_PWREx_EnableUSBVoltageDetector();
+  }
+#endif
 #if defined (USB)
   if (hpcd->Instance == USB) {
 
@@ -82,22 +73,23 @@ void HAL_PCD_MspInit(PCD_HandleTypeDef *hpcd)
     /* Enable USB FS Clock */
     __HAL_RCC_USB_CLK_ENABLE();
 
-#if defined(SYSCFG_CFGR1_USB_IT_RMP) && defined(USE_USB_INTERRUPT_REMAPPED)
-    /* USB interrupt remapping enable */
+#if defined (USE_USB_INTERRUPT_REMAPPED)
+    /*USB interrupt remapping enable */
     __HAL_REMAPINTERRUPT_USB_ENABLE();
 #endif
 
-#if defined(USB_H_IRQn)
-    /* Set USB High priority Interrupt priority */
+#if defined(STM32G4xx) || defined(STM32WBxx)
     HAL_NVIC_SetPriority(USB_HP_IRQn, USBD_IRQ_PRIO, USBD_IRQ_SUBPRIO);
-    /* Enable USB High priority Interrupt */
     HAL_NVIC_EnableIRQ(USB_HP_IRQn);
-#endif
-    /* Set USB Interrupt priority */
+    HAL_NVIC_SetPriority(USB_LP_IRQn, USBD_IRQ_PRIO, USBD_IRQ_SUBPRIO);
+    HAL_NVIC_EnableIRQ(USB_LP_IRQn);
+#else
+    /* Set USB FS Interrupt priority */
     HAL_NVIC_SetPriority(USB_IRQn, USBD_IRQ_PRIO, USBD_IRQ_SUBPRIO);
 
-    /* Enable USB Interrupt */
+    /* Enable USB FS Interrupt */
     HAL_NVIC_EnableIRQ(USB_IRQn);
+#endif /* STM32WBxx */
 
     if (hpcd->Init.low_power_enable == 1) {
       /* Enable EXTI for USB wakeup */
@@ -107,15 +99,13 @@ void HAL_PCD_MspInit(PCD_HandleTypeDef *hpcd)
 #ifdef __HAL_USB_WAKEUP_EXTI_ENABLE_RISING_EDGE
       __HAL_USB_WAKEUP_EXTI_ENABLE_RISING_EDGE();
 #endif
-#ifdef __HAL_USB_WAKEUP_EXTI_ENABLE_IT
       __HAL_USB_WAKEUP_EXTI_ENABLE_IT();
-#endif
-#if defined(USB_WKUP_IRQn)
+#if defined(STM32F1xx) || defined(STM32F3xx)
       /* USB Wakeup Interrupt */
-      HAL_NVIC_EnableIRQ(USB_WKUP_IRQn);
+      HAL_NVIC_EnableIRQ(USBWakeUp_IRQn);
 
       /* Enable USB Wake-up interrupt */
-      HAL_NVIC_SetPriority(USB_WKUP_IRQn, 0, 0);
+      HAL_NVIC_SetPriority(USBWakeUp_IRQn, 0, 0);
 #endif
     }
   }
@@ -147,10 +137,8 @@ void HAL_PCD_MspInit(PCD_HandleTypeDef *hpcd)
 #ifdef __HAL_USB_OTG_FS_WAKEUP_EXTI_ENABLE_RISING_EDGE
       __HAL_USB_OTG_FS_WAKEUP_EXTI_ENABLE_RISING_EDGE();
 #endif
-#ifdef __HAL_USB_OTG_FS_WAKEUP_EXTI_ENABLE_IT
       __HAL_USB_OTG_FS_WAKEUP_EXTI_ENABLE_IT();
-#endif
-#if !defined(STM32L4xx) && !defined(STM32U5xx)
+#if !defined(STM32L4xx)
       /* Set EXTI Wakeup Interrupt priority */
       HAL_NVIC_SetPriority(OTG_FS_WKUP_IRQn, USBD_IRQ_PRIO, USBD_IRQ_SUBPRIO);
 
@@ -175,7 +163,7 @@ void HAL_PCD_MspInit(PCD_HandleTypeDef *hpcd)
     /* Enable USB HS Clocks */
     __HAL_RCC_USB_OTG_HS_CLK_ENABLE();
 
-    /* Set USB HS Interrupt priority */
+    /* Set USBHS Interrupt priority */
     HAL_NVIC_SetPriority(OTG_HS_IRQn, USBD_IRQ_PRIO, USBD_IRQ_SUBPRIO);
 
     /* Enable USB HS Interrupt */
@@ -330,7 +318,7 @@ void HAL_PCD_SuspendCallback(PCD_HandleTypeDef *hpcd)
 void HAL_PCD_ResumeCallback(PCD_HandleTypeDef *hpcd)
 {
   if (hpcd->Init.low_power_enable) {
-    USBD_SystemClockConfigFromResume();
+    SystemClock_Config();
 
     /* Reset SLEEPDEEP bit of Cortex System Control Register */
     SCB->SCR &= (uint32_t)~((uint32_t)(SCB_SCR_SLEEPDEEP_Msk | SCB_SCR_SLEEPONEXIT_Msk));
@@ -381,6 +369,8 @@ void HAL_PCD_DisconnectCallback(PCD_HandleTypeDef *hpcd)
   USBD_LL_DevDisconnected(hpcd->pData);
 }
 
+
+
 /**
   * @brief  This function handles USB-On-The-Go FS/HS global interrupt request.
   * @param  None
@@ -397,20 +387,29 @@ void HAL_PCD_DisconnectCallback(PCD_HandleTypeDef *hpcd)
   HAL_PCD_IRQHandler(&g_hpcd);
 }
 
-#if defined(USB_H_IRQn)
+#if defined(STM32WBxx)
 /**
   * @brief This function handles USB high priority interrupt.
   * @param  None
   * @retval None
   */
-void USB_H_IRQHandler(void)
+void USB_HP_IRQHandler(void)
 {
   HAL_PCD_IRQHandler(&g_hpcd);
 }
-#endif /* USB_H_IRQn */
 
 /**
-  * @brief  This function handles USB Wakeup IRQ Handler.
+  * @brief This function handles USB low priority interrupt, USB wake-up interrupt through EXTI line 28.
+  * @param  None
+  * @retval None
+  */
+void USB_LP_IRQHandler(void)
+{
+  HAL_PCD_IRQHandler(&g_hpcd);
+}
+#else
+/**
+  * @brief  This function handles USB OTG FS Wakeup IRQ Handler.
   * @param  None
   * @retval None
   */
@@ -418,18 +417,17 @@ void USB_H_IRQHandler(void)
   void OTG_HS_WKUP_IRQHandler(void)
 #elif defined(USB_OTG_FS)
   void OTG_FS_WKUP_IRQHandler(void)
-#elif defined(USB_WKUP_IRQHandler)
-  void USB_WKUP_IRQHandler(void)
 #else
-  void USBWakeUp_IRQHandler_dummy(void)
+  void USBWakeUp_IRQHandler(void)
 #endif
 {
   if ((&g_hpcd)->Init.low_power_enable) {
     /* Reset SLEEPDEEP bit of Cortex System Control Register */
     SCB->SCR &= (uint32_t)~((uint32_t)(SCB_SCR_SLEEPDEEP_Msk | SCB_SCR_SLEEPONEXIT_Msk));
 
-    /* Configures system clock after wake-up */
-    USBD_SystemClockConfigFromResume();
+    /* Configures system clock after wake-up from STOP: enable HSE, PLL and select
+    PLL as system clock source (HSE and PLL are disabled in STOP mode) */
+    SystemClock_Config();
 
     /* ungate PHY clock */
     __HAL_PCD_UNGATE_PHYCLOCK((&g_hpcd));
@@ -444,7 +442,7 @@ void USB_H_IRQHandler(void)
   __HAL_USB_WAKEUP_EXTI_CLEAR_FLAG();
 #endif
 }
-
+#endif
 /*******************************************************************************
                        LL Driver Interface (USB Device Library --> PCD)
 *******************************************************************************/
@@ -646,11 +644,10 @@ uint8_t USBD_LL_IsStallEP(USBD_HandleTypeDef *pdev, uint8_t ep_addr)
 /**
   * @brief  Assigns a USB address to the device.
   * @param  pdev: Device handle
-  * @param  dev_addr: Endpoint Number
+  * @param  ep_addr: Endpoint Number
   * @retval USBD Status
   */
-USBD_StatusTypeDef USBD_LL_SetUSBAddress(USBD_HandleTypeDef *pdev,
-                                         uint8_t dev_addr)
+USBD_StatusTypeDef USBD_LL_SetUSBAddress(USBD_HandleTypeDef *pdev, uint8_t dev_addr)
 {
   HAL_PCD_SetAddress(pdev->pData, dev_addr);
   return USBD_OK;
@@ -664,8 +661,10 @@ USBD_StatusTypeDef USBD_LL_SetUSBAddress(USBD_HandleTypeDef *pdev,
   * @param  size: Data size
   * @retval USBD Status
   */
-USBD_StatusTypeDef USBD_LL_Transmit(USBD_HandleTypeDef *pdev, uint8_t ep_addr,
-                                    uint8_t *pbuf, uint32_t size)
+USBD_StatusTypeDef USBD_LL_Transmit(USBD_HandleTypeDef *pdev,
+                                    uint8_t ep_addr,
+                                    uint8_t *pbuf,
+                                    uint32_t size)
 {
   HAL_PCD_EP_Transmit(pdev->pData, ep_addr, pbuf, size);
   return USBD_OK;
@@ -680,7 +679,8 @@ USBD_StatusTypeDef USBD_LL_Transmit(USBD_HandleTypeDef *pdev, uint8_t ep_addr,
   * @retval USBD Status
   */
 USBD_StatusTypeDef USBD_LL_PrepareReceive(USBD_HandleTypeDef *pdev,
-                                          uint8_t ep_addr, uint8_t *pbuf,
+                                          uint8_t ep_addr,
+                                          uint8_t *pbuf,
                                           uint32_t size)
 {
   HAL_PCD_EP_Receive(pdev->pData, ep_addr, pbuf, size);
