@@ -33,8 +33,6 @@ static PinName g_current_pin = NC;
 #ifndef ADC_SAMPLINGTIME
 #if defined(ADC_SAMPLETIME_8CYCLES_5)
 #define ADC_SAMPLINGTIME        ADC_SAMPLETIME_8CYCLES_5;
-#elif defined(ADC_SAMPLETIME_12CYCLES)
-#define ADC_SAMPLINGTIME        ADC_SAMPLETIME_12CYCLES;
 #elif defined(ADC_SAMPLETIME_12CYCLES_5)
 #define ADC_SAMPLINGTIME        ADC_SAMPLETIME_12CYCLES_5;
 #elif defined(ADC_SAMPLETIME_13CYCLES_5)
@@ -48,14 +46,6 @@ static PinName g_current_pin = NC;
 #endif
 #endif /* !ADC_SAMPLINGTIME */
 
-#if defined(ADC_VER_V5_V90) && !defined(ADC3_SAMPLINGTIME)
-#define ADC3_SAMPLINGTIME       ADC3_SAMPLETIME_24CYCLES_5;
-#endif
-
-#if defined(ADC4_SAMPLETIME_19CYCLES_5) && !defined(ADC4_SAMPLINGTIME)
-#define ADC4_SAMPLINGTIME       ADC4_SAMPLETIME_19CYCLES_5;
-#endif
-
 /*
  * Minimum ADC sampling time is required when reading
  * internal channels so set it to max possible value.
@@ -70,8 +60,6 @@ static PinName g_current_pin = NC;
 #define ADC_SAMPLINGTIME_INTERNAL ADC_SAMPLETIME_384CYCLES
 #elif defined(ADC_SAMPLETIME_810CYCLES_5)
 #define ADC_SAMPLINGTIME_INTERNAL ADC_SAMPLETIME_810CYCLES_5
-#elif defined(ADC_SAMPLETIME_814CYCLES)
-#define ADC_SAMPLINGTIME_INTERNAL ADC_SAMPLETIME_814CYCLES
 #elif defined(ADC_SAMPLETIME_640CYCLES_5)
 #define ADC_SAMPLINGTIME_INTERNAL ADC_SAMPLETIME_640CYCLES_5
 #elif defined(ADC_SAMPLETIME_601CYCLES_5)
@@ -92,8 +80,8 @@ static PinName g_current_pin = NC;
 #define ADC_CLOCK_DIV       ADC_CLOCK_SYNC_PCLK_DIV4
 #elif ADC_CLOCK_SYNC_PCLK_DIV2
 #define ADC_CLOCK_DIV       ADC_CLOCK_SYNC_PCLK_DIV2
-#elif defined(ADC_CLOCK_ASYNC_DIV4)
-#define ADC_CLOCK_DIV       ADC_CLOCK_ASYNC_DIV4
+#elif defined(ADC_CLOCK_ASYNC_DIV1)
+#define ADC_CLOCK_DIV       ADC_CLOCK_ASYNC_DIV1
 #endif
 #endif /* !ADC_CLOCK_DIV */
 
@@ -101,14 +89,8 @@ static PinName g_current_pin = NC;
 #define ADC_REGULAR_RANK_1  1
 #endif
 
-/* Exported Functions */
-/**
-  * @brief  Return ADC HAL channel linked to a PinName
-  * @param  pin: PinName
-  * @param  bank: pointer to get ADC channel bank if required
-  * @retval Valid HAL channel
-  */
-uint32_t get_adc_channel(PinName pin, uint32_t *bank)
+/* Private Functions */
+static uint32_t get_adc_channel(PinName pin, uint32_t *bank)
 {
   uint32_t function = pinmap_function(pin, PinMap_ADC);
   uint32_t channel = 0;
@@ -191,11 +173,9 @@ uint32_t get_adc_channel(PinName pin, uint32_t *bank)
     case 22:
       channel = ADC_CHANNEL_22;
       break;
-#ifdef ADC_CHANNEL_23
     case 23:
       channel = ADC_CHANNEL_23;
       break;
-#ifdef ADC_CHANNEL_24
     case 24:
       channel = ADC_CHANNEL_24;
       break;
@@ -222,11 +202,9 @@ uint32_t get_adc_channel(PinName pin, uint32_t *bank)
       channel = ADC_CHANNEL_31;
       break;
 #endif
-#endif
-#endif
 #endif
     default:
-      _Error_Handler("ADC: Unknown adc channel", (int)(STM_PIN_CHANNEL(function)));
+      channel = 0;
       break;
   }
 #ifdef ADC_CHANNELS_BANK_B
@@ -241,14 +219,7 @@ uint32_t get_adc_channel(PinName pin, uint32_t *bank)
   return channel;
 }
 
-/**
-  * @brief  Return ADC HAL internal channel linked to a PinName
-  * @param  pin: specific PinName's for ADC internal. Value can be:
-  *         PADC_TEMP, PADC_TEMP_ADC5, PADC_VREF, PADC_VBAT
-  *         Note that not all of these values ​​may be available for all series.
-  * @retval Valid HAL internal channel.
-  */
-uint32_t get_adc_internal_channel(PinName pin)
+static uint32_t get_adc_internal_channel(PinName pin)
 {
   uint32_t channel = 0;
   switch (pin) {
@@ -278,20 +249,41 @@ uint32_t get_adc_internal_channel(PinName pin)
       break;
 #endif
     default:
-      _Error_Handler("ADC: Unknown adc internal PiName", (int)(pin));
+      channel = 0;
       break;
   }
   return channel;
 }
 #endif /* HAL_ADC_MODULE_ENABLED && !HAL_ADC_MODULE_ONLY */
 
+#if defined(HAL_TIM_MODULE_ENABLED) && !defined(HAL_TIM_MODULE_ONLY)
+uint32_t get_pwm_channel(PinName pin)
+{
+  uint32_t function = pinmap_function(pin, PinMap_TIM);
+  uint32_t channel = 0;
+  switch (STM_PIN_CHANNEL(function)) {
+    case 1:
+      channel = TIM_CHANNEL_1;
+      break;
+    case 2:
+      channel = TIM_CHANNEL_2;
+      break;
+    case 3:
+      channel = TIM_CHANNEL_3;
+      break;
+    case 4:
+      channel = TIM_CHANNEL_4;
+      break;
+    default:
+      channel = 0;
+      break;
+  }
+  return channel;
+}
+#endif /* HAL_TIM_MODULE_ENABLED && !HAL_TIM_MODULE_ONLY */
+
 #if defined(HAL_DAC_MODULE_ENABLED) && !defined(HAL_DAC_MODULE_ONLY)
-/**
-  * @brief  Return DAC HAL channel linked to a PinName
-  * @param  pin: specific PinName's for ADC internal.
-  * @retval Valid HAL channel
-  */
-uint32_t get_dac_channel(PinName pin)
+static uint32_t get_dac_channel(PinName pin)
 {
   uint32_t function = pinmap_function(pin, PinMap_DAC);
   uint32_t channel = 0;
@@ -310,7 +302,7 @@ uint32_t get_dac_channel(PinName pin)
       break;
 #endif
     default:
-      _Error_Handler("DAC: Unknown dac channel", (int)(STM_PIN_CHANNEL(function)));
+      channel = 0;
       break;
   }
   return channel;
@@ -596,9 +588,6 @@ void HAL_ADC_MspInit(ADC_HandleTypeDef *hadc)
 #endif
 #ifdef ADC4
   else if (hadc->Instance == ADC4) {
-#ifdef __HAL_RCC_ADC4_CLK_ENABLE
-    __HAL_RCC_ADC4_CLK_ENABLE();
-#endif
 #ifdef __HAL_RCC_ADC34_CLK_ENABLE
     __HAL_RCC_ADC34_CLK_ENABLE();
 #endif
@@ -718,15 +707,6 @@ void HAL_ADC_MspDeInit(ADC_HandleTypeDef *hadc)
 #endif
 #ifdef ADC4
   else if (hadc->Instance == ADC4) {
-#ifdef __HAL_RCC_ADC4_FORCE_RESET
-    __HAL_RCC_ADC4_FORCE_RESET();
-#endif
-#ifdef __HAL_RCC_ADC4_RELEASE_RESET
-    __HAL_RCC_ADC4_RELEASE_RESET();
-#endif
-#ifdef __HAL_RCC_ADC4_CLK_DISABLE
-    __HAL_RCC_ADC4_CLK_DISABLE();
-#endif
 #ifdef __HAL_RCC_ADC34_FORCE_RESET
     __HAL_RCC_ADC34_FORCE_RESET();
 #endif
@@ -775,12 +755,8 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   uint32_t bank = 0;
 
   if ((pin & PADC_BASE) && (pin < ANA_START)) {
-#if defined(STM32H7xx) || defined(STM32MP1xx)
-#ifdef ADC3
+#if defined(STM32H7xx)
     AdcHandle.Instance = ADC3;
-#else
-    AdcHandle.Instance = ADC2;
-#endif
 #else
     AdcHandle.Instance = ADC1;
 #if defined(ADC5) && defined(ADC_CHANNEL_TEMPSENSOR_ADC5)
@@ -794,16 +770,6 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   } else {
     AdcHandle.Instance = (ADC_TypeDef *)pinmap_peripheral(pin, PinMap_ADC);
     channel = get_adc_channel(pin, &bank);
-#if defined(ADC_VER_V5_V90)
-    if (AdcHandle.Instance == ADC3) {
-      samplingTime = ADC3_SAMPLINGTIME;
-    }
-#endif
-#if defined(ADC4_SAMPLINGTIME)
-    if (AdcHandle.Instance == ADC4) {
-      samplingTime = ADC4_SAMPLINGTIME;
-    }
-#endif
   }
 
   if (AdcHandle.Instance == NP) {
@@ -856,14 +822,13 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   AdcHandle.Init.EOCSelection          = ADC_EOC_SINGLE_CONV;           /* EOC flag picked-up to indicate conversion end */
 #endif
 #if !defined(STM32F1xx) && !defined(STM32F2xx) && !defined(STM32F4xx) && \
-    !defined(STM32F7xx) && !defined(ADC1_V2_5)
+    !defined(STM32F7xx) && !defined(STM32F373xC) && !defined(STM32F378xx)
   AdcHandle.Init.LowPowerAutoWait      = DISABLE;                       /* Auto-delayed conversion feature disabled */
 #endif
 #if !defined(STM32F1xx) && !defined(STM32F2xx) && !defined(STM32F3xx) && \
     !defined(STM32F4xx) && !defined(STM32F7xx) && !defined(STM32G4xx) && \
-    !defined(STM32H5xx) && !defined(STM32H7xx) && !defined(STM32L4xx) &&  \
-    !defined(STM32L5xx) && !defined(STM32MP1xx) && !defined(STM32WBxx) || \
-    defined(ADC_SUPPORT_2_5_MSPS)
+    !defined(STM32H7xx) && !defined(STM32L4xx) && !defined(STM32L5xx) && \
+    !defined(STM32MP1xx) && !defined(STM32WBxx)
   AdcHandle.Init.LowPowerAutoPowerOff  = DISABLE;                       /* ADC automatically powers-off after a conversion and automatically wakes-up when a new conversion is triggered */
 #endif
 #ifdef ADC_CHANNELS_BANK_B
@@ -876,16 +841,15 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   AdcHandle.Init.NbrOfConversion       = 1;                             /* Specifies the number of ranks that will be converted within the regular group sequencer. */
 #endif
   AdcHandle.Init.DiscontinuousConvMode = DISABLE;                       /* Parameter discarded because sequencer is disabled */
-#if !defined(STM32C0xx) && !defined(STM32F0xx) && !defined(STM32G0xx) && \
-    !defined(STM32L0xx) && !defined(STM32WLxx) && !defined(ADC_SUPPORT_2_5_MSPS)
+#if !defined(STM32F0xx) && !defined(STM32G0xx) && !defined(STM32L0xx)
   AdcHandle.Init.NbrOfDiscConversion   = 0;                             /* Parameter discarded because sequencer is disabled */
 #endif
   AdcHandle.Init.ExternalTrigConv      = ADC_SOFTWARE_START;            /* Software start to trig the 1st conversion manually, without external event */
-#if !defined(STM32F1xx) && !defined(ADC1_V2_5)
+#if !defined(STM32F1xx) && !defined(STM32F373xC) && !defined(STM32F378xx)
   AdcHandle.Init.ExternalTrigConvEdge  = ADC_EXTERNALTRIGCONVEDGE_NONE; /* Parameter discarded because software trigger chosen */
 #endif
 #if !defined(STM32F1xx) && !defined(STM32H7xx) && !defined(STM32MP1xx) && \
-    !defined(ADC1_V2_5)
+    !defined(STM32F373xC) && !defined(STM32F378xx)
   AdcHandle.Init.DMAContinuousRequests = DISABLE;                       /* DMA one-shot mode selected (not applied to this example) */
 #endif
 #ifdef ADC_CONVERSIONDATA_DR
@@ -895,14 +859,13 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   AdcHandle.Init.Overrun               = ADC_OVR_DATA_OVERWRITTEN;      /* DR register is overwritten with the last conversion result in case of overrun */
 #endif
 #ifdef ADC_LEFTBITSHIFT_NONE
-  AdcHandle.Init.LeftBitShift          = ADC_LEFTBITSHIFT_NONE;         /* No bit shift left applied on the final ADC conversion data */
+  AdcHandle.Init.LeftBitShift          = ADC_LEFTBITSHIFT_NONE;         /* No bit shift left applied on the final ADC convesion data */
 #endif
 
 #if defined(STM32F0xx)
   AdcHandle.Init.SamplingTimeCommon    = samplingTime;
 #endif
-#if defined(STM32C0xx) || defined(STM32G0xx) || defined(STM32U5xx) || \
-    defined(STM32WLxx) || defined(ADC_SUPPORT_2_5_MSPS)
+#if defined(STM32G0xx)
   AdcHandle.Init.SamplingTimeCommon1   = samplingTime;              /* Set sampling time common to a group of channels. */
   AdcHandle.Init.SamplingTimeCommon2   = samplingTime;              /* Set sampling time common to a group of channels, second common setting possible.*/
 #endif
@@ -912,7 +875,7 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
 #endif
 #if !defined(STM32F0xx) && !defined(STM32F1xx) && !defined(STM32F2xx) && \
     !defined(STM32F3xx) && !defined(STM32F4xx) && !defined(STM32F7xx) && \
-    !defined(STM32L1xx) && !defined(ADC_SUPPORT_2_5_MSPS)
+    !defined(STM32L1xx)
   AdcHandle.Init.OversamplingMode      = DISABLE;
   /* AdcHandle.Init.Oversample ignore for STM32L0xx as oversampling disabled */
   /* AdcHandle.Init.Oversampling ignored for other as oversampling disabled */
@@ -923,9 +886,6 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
 #ifdef ADC_TRIGGER_FREQ_HIGH
   AdcHandle.Init.TriggerFrequencyMode  = ADC_TRIGGER_FREQ_HIGH;
 #endif
-#ifdef ADC_VREF_PPROT_NONE
-  AdcHandle.Init.VrefProtection = ADC_VREF_PPROT_NONE;
-#endif
 
   AdcHandle.State = HAL_ADC_STATE_RESET;
   AdcHandle.DMA_Handle = NULL;
@@ -940,15 +900,16 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
 
   AdcChannelConf.Channel      = channel;                          /* Specifies the channel to configure into ADC */
 
-#if defined(STM32G4xx) || defined(STM32H5xx) || defined(STM32L4xx) || \
-    defined(STM32L5xx) || defined(STM32WBxx)
+#if defined(STM32L4xx) || defined(STM32L5xx) || defined(STM32WBxx)
+  if (!IS_ADC_CHANNEL(&AdcHandle, AdcChannelConf.Channel)) {
+#elif defined(STM32G4xx)
   if (!IS_ADC_CHANNEL(&AdcHandle, AdcChannelConf.Channel)) {
 #else
   if (!IS_ADC_CHANNEL(AdcChannelConf.Channel)) {
-#endif
+#endif /* STM32L4xx || STM32WBxx */
     return 0;
   }
-#if defined(ADC_SCAN_SEQ_FIXED) && defined(ADC_RANK_CHANNEL_NUMBER)
+#ifdef ADC_SCAN_SEQ_FIXED
   AdcChannelConf.Rank         = ADC_RANK_CHANNEL_NUMBER;          /* Enable the rank of the selected channels when not fully configurable */
 #else
   AdcChannelConf.Rank         = ADC_REGULAR_RANK_1;               /* Specifies the rank in the regular group sequencer */
@@ -960,14 +921,16 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
   AdcChannelConf.SamplingTime = ADC_SAMPLINGTIME_COMMON_1;        /* Sampling time value to be set for the selected channel */
 #endif
 #endif
-#if defined(ADC_DIFFERENTIAL_ENDED) && !defined(ADC1_V2_5)
+#if !defined(STM32F0xx) && !defined(STM32F1xx) && !defined(STM32F2xx) && \
+    !defined(STM32F4xx) && !defined(STM32F7xx) && !defined(STM32G0xx) && \
+    !defined(STM32L0xx) && !defined(STM32L1xx) && \
+    !defined(STM32F373xC) && !defined(STM32F378xx)
   AdcChannelConf.SingleDiff   = ADC_SINGLE_ENDED;                 /* Single-ended input channel */
   AdcChannelConf.OffsetNumber = ADC_OFFSET_NONE;                  /* No offset subtraction */
 #endif
-#if !defined(STM32C0xx) && !defined(STM32F0xx) && !defined(STM32F1xx) && \
-    !defined(STM32F2xx) && !defined(STM32G0xx) && !defined(STM32L0xx) && \
-    !defined(STM32L1xx) && !defined(STM32WBxx) && !defined(STM32WLxx) && \
-    !defined(ADC1_V2_5)
+#if !defined(STM32F0xx) && !defined(STM32F1xx) && !defined(STM32F2xx) && \
+    !defined(STM32G0xx) && !defined(STM32L0xx) && !defined(STM32L1xx) && \
+    !defined(STM32WBxx) && !defined(STM32F373xC) && !defined(STM32F378xx)
   AdcChannelConf.Offset = 0;                                      /* Parameter discarded because offset correction is disabled */
 #endif
 #if defined (STM32H7xx) || defined(STM32MP1xx)
@@ -981,14 +944,18 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
     return 0;
   }
 
-#if defined(ADC_CR_ADCAL) || defined(ADC_CR2_RSTCAL)
+#if defined(STM32F0xx) || defined(STM32F1xx) || defined(STM32F3xx) || \
+    defined(STM32G0xx) || defined(STM32G4xx) || defined(STM32H7xx) || \
+    defined(STM32L0xx) || defined(STM32L4xx) || defined(STM32MP1xx) || \
+    defined(STM32WBxx)
   /*##-2.1- Calibrate ADC then Start the conversion process ####################*/
-#if defined(ADC_CALIB_OFFSET)
-  if (HAL_ADCEx_Calibration_Start(&AdcHandle, ADC_CALIB_OFFSET, ADC_SINGLE_ENDED) != HAL_OK)
-#elif defined(ADC_SINGLE_ENDED) && !defined(ADC1_V2_5)
-  if (HAL_ADCEx_Calibration_Start(&AdcHandle, ADC_SINGLE_ENDED) !=  HAL_OK)
-#else
+#if defined(STM32F0xx) || defined(STM32G0xx) || defined(STM32F1xx) || \
+    defined(STM32F373xC) || defined(STM32F378xx)
   if (HAL_ADCEx_Calibration_Start(&AdcHandle) !=  HAL_OK)
+#elif defined (STM32H7xx) || defined(STM32MP1xx)
+  if (HAL_ADCEx_Calibration_Start(&AdcHandle, ADC_CALIB_OFFSET, ADC_SINGLE_ENDED) != HAL_OK)
+#else
+  if (HAL_ADCEx_Calibration_Start(&AdcHandle, ADC_SINGLE_ENDED) !=  HAL_OK)
 #endif
   {
     /* ADC Calibration Error */
@@ -998,7 +965,7 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
 
   /*##-3- Start the conversion process ####################*/
   if (HAL_ADC_Start(&AdcHandle) != HAL_OK) {
-    /* Start Conversion Error */
+    /* Start Conversation Error */
     return 0;
   }
 
@@ -1011,7 +978,7 @@ uint16_t adc_read_value(PinName pin, uint32_t resolution)
     return 0;
   }
 
-  /* Check if the continuous conversion of regular channel is finished */
+  /* Check if the continous conversion of regular channel is finished */
   if ((HAL_ADC_GetState(&AdcHandle) & HAL_ADC_STATE_REG_EOC) == HAL_ADC_STATE_REG_EOC) {
     /*##-5- Get the converted value of regular channel  ########################*/
     uhADCxConvertedValue = HAL_ADC_GetValue(&AdcHandle);
