@@ -36,7 +36,7 @@ extern "C" {
 #define DEBUG_UART_BAUDRATE 9600
 #endif
 
-/* @brief uart characteristics */
+/* @brief uart caracteristics */
 typedef enum {
 #if defined(USART1_BASE)
   UART1_INDEX,
@@ -70,22 +70,13 @@ typedef enum {
 #endif
 #if defined(LPUART1_BASE)
   LPUART1_INDEX,
-#endif
-#if defined(LPUART2_BASE)
-  LPUART2_INDEX,
 #endif
   UART_NUM
 } uart_index_t;
 
 static UART_HandleTypeDef *uart_handlers[UART_NUM] = {NULL};
-static serial_t serial_debug = {
-  .uart = NP,
-  .pin_tx = NC,
-  .pin_rx = NC,
-  .pin_rts = NC,
-  .pin_cts = NC,
-  .index = UART_NUM
-};
+
+static serial_t serial_debug = { .uart = NP, .index = UART_NUM };
 
 /* Aim of the function is to get serial_s pointer using huart pointer */
 /* Highly inspired from magical linux kernel's "container_of" */
@@ -116,35 +107,15 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
   /* Determine the U(S)ART peripheral to use (USART1, USART2, ...) */
   USART_TypeDef *uart_tx = pinmap_peripheral(obj->pin_tx, PinMap_UART_TX);
   USART_TypeDef *uart_rx = pinmap_peripheral(obj->pin_rx, PinMap_UART_RX);
-  USART_TypeDef *uart_rts = pinmap_peripheral(obj->pin_rts, PinMap_UART_RTS);
-  USART_TypeDef *uart_cts = pinmap_peripheral(obj->pin_cts, PinMap_UART_CTS);
 
   /* Pin Tx must not be NP */
   if (uart_tx == NP) {
-    if (obj != &serial_debug) {
-      core_debug("ERROR: [U(S)ART] Tx pin has no peripheral!\n");
-    }
+    core_debug("ERROR: [U(S)ART] Tx pin has no peripheral!\n");
     return;
   }
   /* Pin Rx must not be NP if not half-duplex */
   if ((obj->pin_rx != NC) && (uart_rx == NP)) {
-    if (obj != &serial_debug) {
-      core_debug("ERROR: [U(S)ART] Rx pin has no peripheral!\n");
-    }
-    return;
-  }
-  /* Pin RTS must not be NP if flow control is enabled */
-  if ((obj->pin_rts != NC) && (uart_rts == NP)) {
-    if (obj != &serial_debug) {
-      core_debug("ERROR: [U(S)ART] RTS pin has no peripheral!\n");
-    }
-    return;
-  }
-  /* Pin CTS must not be NP if flow control is enabled */
-  if ((obj->pin_cts != NC) && (uart_cts == NP)) {
-    if (obj != &serial_debug) {
-      core_debug("ERROR: [U(S)ART] CTS pin has no peripheral!\n");
-    }
+    core_debug("ERROR: [U(S)ART] Rx pin has no peripheral!\n");
     return;
   }
 
@@ -153,14 +124,9 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
    * and assign it to the object
    */
   obj->uart = pinmap_merge_peripheral(uart_tx, uart_rx);
-  /* We also merge RTS/CTS and assert all pins belong to the same instance */
-  obj->uart = pinmap_merge_peripheral(obj->uart, uart_rts);
-  obj->uart = pinmap_merge_peripheral(obj->uart, uart_cts);
 
   if (obj->uart == NP) {
-    if (obj != &serial_debug) {
-      core_debug("ERROR: [U(S)ART] Rx/Tx/RTS/CTS pins peripherals mismatch!\n");
-    }
+    core_debug("ERROR: [U(S)ART] Rx and Tx pins peripherals mismatch!\n");
     return;
   }
 
@@ -244,15 +210,6 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
     obj->irq = LPUART1_IRQn;
   }
 #endif
-#if defined(LPUART2_BASE)
-  else if (obj->uart == LPUART2) {
-    __HAL_RCC_LPUART2_FORCE_RESET();
-    __HAL_RCC_LPUART2_RELEASE_RESET();
-    __HAL_RCC_LPUART2_CLK_ENABLE();
-    obj->index = LPUART2_INDEX;
-    obj->irq = LPUART2_IRQn;
-  }
-#endif
 #if defined(UART7_BASE)
   else if (obj->uart == UART7) {
     __HAL_RCC_UART7_FORCE_RESET();
@@ -321,17 +278,6 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
     pinmap_pinout(obj->pin_rx, PinMap_UART_RX);
   }
 
-  /* Configure flow control */
-  uint32_t flow_control = UART_HWCONTROL_NONE;
-  if (uart_rts != NP) {
-    flow_control |= UART_HWCONTROL_RTS;
-    pinmap_pinout(obj->pin_rts, PinMap_UART_RTS);
-  }
-  if (uart_cts != NP) {
-    flow_control |= UART_HWCONTROL_CTS;
-    pinmap_pinout(obj->pin_cts, PinMap_UART_CTS);
-  }
-
   /* Configure uart */
   uart_handlers[obj->index] = huart;
   huart->Instance          = (USART_TypeDef *)(obj->uart);
@@ -340,7 +286,7 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
   huart->Init.StopBits     = stopbits;
   huart->Init.Parity       = parity;
   huart->Init.Mode         = UART_MODE_TX_RX;
-  huart->Init.HwFlowCtl    = flow_control;
+  huart->Init.HwFlowCtl    = UART_HWCONTROL_NONE;
   huart->Init.OverSampling = UART_OVERSAMPLING_16;
 #if !defined(STM32F1xx) && !defined(STM32F2xx) && !defined(STM32F4xx)\
  && !defined(STM32L1xx)
@@ -353,17 +299,13 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
   /* Set the NVIC priority for future interrupts */
   HAL_NVIC_SetPriority(obj->irq, UART_IRQ_PRIO, UART_IRQ_SUBPRIO);
 
-#if defined(LPUART1_BASE) || defined(LPUART2_BASE)
+#if defined(LPUART1_BASE)
   /*
    * Note that LPUART clock source must be in the range
    * [3 x baud rate, 4096 x baud rate]
    * check Reference Manual
    */
-  if ((obj->uart == LPUART1)
-#if defined(LPUART2_BASE)
-      || (obj->uart == LPUART2)
-#endif
-     ) {
+  if (obj->uart == LPUART1) {
     if (baudrate <= 9600) {
 #if defined(USART_CR3_UCESM)
       HAL_UARTEx_EnableClockStopMode(huart);
@@ -376,11 +318,7 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
       HAL_UARTEx_DisableStopMode(huart);
     }
     /* Trying default LPUART clock source */
-    if (uart_rx == NP) {
-      if (HAL_HalfDuplex_Init(huart) == HAL_OK) {
-        return;
-      }
-    } else if (HAL_UART_Init(huart) == HAL_OK) {
+    if (HAL_UART_Init(huart) == HAL_OK) {
       return;
     }
     /* Trying to change LPUART clock source */
@@ -388,69 +326,26 @@ void uart_init(serial_t *obj, uint32_t baudrate, uint32_t databits, uint32_t par
     if (baudrate <= 9600) {
       /* Enable the clock if not already set by user */
       enableClock(LSE_CLOCK);
-      if (obj->uart == LPUART1) {
-        __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_LSE);
-      }
-#if defined(LPUART2_BASE)
-      if (obj->uart == LPUART2) {
-        __HAL_RCC_LPUART2_CONFIG(RCC_LPUART2CLKSOURCE_LSE);
-      }
-#endif
-      if (uart_rx == NP) {
-        if (HAL_HalfDuplex_Init(huart) == HAL_OK) {
-          return;
-        }
-      } else if (HAL_UART_Init(huart) == HAL_OK) {
+
+      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_LSE);
+      if (HAL_UART_Init(huart) == HAL_OK) {
         return;
       }
     }
     if (__HAL_RCC_GET_FLAG(RCC_FLAG_HSIRDY)) {
-      if (obj->uart == LPUART1) {
-        __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_HSI);
-      }
-#if defined(LPUART2_BASE)
-      if (obj->uart == LPUART2) {
-        __HAL_RCC_LPUART2_CONFIG(RCC_LPUART2CLKSOURCE_HSI);
-      }
-#endif
-      if (uart_rx == NP) {
-        if (HAL_HalfDuplex_Init(huart) == HAL_OK) {
-          return;
-        }
-      } else if (HAL_UART_Init(huart) == HAL_OK) {
+      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_HSI);
+      if (HAL_UART_Init(huart) == HAL_OK) {
         return;
       }
     }
-    if (obj->uart == LPUART1) {
-#if defined(RCC_LPUART1CLKSOURCE_CSI)
-      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_CSI);
-#elif defined(RCC_LPUART1CLKSOURCE_PCLK1)
-      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_PCLK1);
-#elif defined(RCC_LPUART1CLKSOURCE_PCLK3)
-      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_PCLK3);
-#endif
-    }
-#if defined(LPUART2_BASE)
-    if (obj->uart == LPUART2) {
-      __HAL_RCC_LPUART2_CONFIG(RCC_LPUART2CLKSOURCE_PCLK1);
-    }
-#endif
-    if (uart_rx == NP) {
-      if (HAL_HalfDuplex_Init(huart) == HAL_OK) {
-        return;
-      }
-    } else if (HAL_UART_Init(huart) == HAL_OK) {
+#ifndef STM32H7xx
+    __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_PCLK1);
+    if (HAL_UART_Init(huart) == HAL_OK) {
       return;
     }
-#if defined(RCC_LPUART1CLKSOURCE_SYSCLK)
-    if (obj->uart == LPUART1) {
-      __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_SYSCLK);
-    }
-#endif
-#if defined(LPUART2_BASE)
-    if (obj->uart == LPUART2) {
-      __HAL_RCC_LPUART2_CONFIG(RCC_LPUART2CLKSOURCE_SYSCLK);
-    }
+    __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_SYSCLK);
+#else
+    __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_CSI);
 #endif
   }
 #endif
@@ -534,13 +429,6 @@ void uart_deinit(serial_t *obj)
       __HAL_RCC_LPUART1_CLK_DISABLE();
       break;
 #endif
-#if defined(LPUART2_BASE)
-    case LPUART2_INDEX:
-      __HAL_RCC_LPUART2_FORCE_RESET();
-      __HAL_RCC_LPUART2_RELEASE_RESET();
-      __HAL_RCC_LPUART2_CLK_DISABLE();
-      break;
-#endif
 #if defined(UART7_BASE)
     case UART7_INDEX:
       __HAL_RCC_UART7_FORCE_RESET();
@@ -598,7 +486,7 @@ void uart_deinit(serial_t *obj)
   }
 }
 
-#if defined(HAL_PWR_MODULE_ENABLED) && (defined(UART_IT_WUF) || defined(LPUART1_BASE))
+#if defined(HAL_PWR_MODULE_ENABLED) && defined(UART_IT_WUF)
 /**
   * @brief  Function called to configure the uart interface for low power
   * @param  obj : pointer to serial_t structure
@@ -652,30 +540,32 @@ void uart_config_lowpower(serial_t *obj)
 #endif
 #if defined(LPUART1_BASE) && defined(__HAL_RCC_LPUART1_CONFIG)
     case LPUART1_INDEX:
-#ifdef __HAL_RCC_LPUART1_CLKAM_ENABLE
-      __HAL_RCC_LPUART1_CLKAM_ENABLE();
-#endif
       if (__HAL_RCC_GET_LPUART1_SOURCE() != RCC_LPUART1CLKSOURCE_HSI) {
         __HAL_RCC_LPUART1_CONFIG(RCC_LPUART1CLKSOURCE_HSI);
       }
       break;
-#endif
-#if defined(LPUART2_BASE) && defined(__HAL_RCC_LPUART2_CONFIG)
-    case LPUART2_INDEX:
-      if (__HAL_RCC_GET_LPUART2_SOURCE() != RCC_LPUART2CLKSOURCE_HSI) {
-        __HAL_RCC_LPUART2_CONFIG(RCC_LPUART2CLKSOURCE_HSI);
-      }
-      break;
 #endif
   }
-#if defined(UART_WAKEUP_EXTI_LINE)
-  /* Enable EXTI wakeup interrupt if defined */
-  LL_EXTI_EnableIT_0_31(UART_WAKEUP_EXTI_LINE);
-#endif
   hsem_unlock(CFG_HW_RCC_CRRCR_CCIPR_SEMID);
 }
 #endif
 
+/**
+  * @brief  write the data on the uart
+  * @param  obj : pointer to serial_t structure
+  * @param  data : byte to write
+  * @param  size : number of data to write
+  * @retval The number of bytes written
+  */
+size_t uart_write(serial_t *obj, uint8_t data, uint16_t size)
+{
+  if (HAL_UART_Transmit(uart_handlers[obj->index], &data, size, TX_TIMEOUT) == HAL_OK) {
+    return size;
+  } else {
+    return 0;
+  }
+}
+
 /**
   * @brief  Function called to initialize the debug uart interface
   * @note   Call only if debug U(S)ART peripheral is not already initialized
@@ -686,12 +576,13 @@ void uart_config_lowpower(serial_t *obj)
 void uart_debug_init(void)
 {
   if (DEBUG_UART != NP) {
+    serial_debug.pin_rx = pinmap_pin(DEBUG_UART, PinMap_UART_RX);
 #if defined(DEBUG_PINNAME_TX)
     serial_debug.pin_tx = DEBUG_PINNAME_TX;
 #else
     serial_debug.pin_tx = pinmap_pin(DEBUG_UART, PinMap_UART_TX);
 #endif
-    /* serial_debug.pin_rx set by default to NC to configure in half duplex mode */
+
     uart_init(&serial_debug, DEBUG_UART_BAUDRATE, UART_WORDLENGTH_8B, UART_PARITY_NONE, UART_STOPBITS_1);
   }
 }
@@ -705,13 +596,11 @@ void uart_debug_init(void)
 size_t uart_debug_write(uint8_t *data, uint32_t size)
 {
   uint32_t tickstart = HAL_GetTick();
-  serial_t *obj = NULL;
 
+  if (DEBUG_UART == NP) {
+    return 0;
+  }
   if (serial_debug.index >= UART_NUM) {
-    if (DEBUG_UART == NP) {
-      return 0;
-    }
-
     /* Search if DEBUG_UART already initialized */
     for (serial_debug.index = 0; serial_debug.index < UART_NUM; serial_debug.index++) {
       if (uart_handlers[serial_debug.index] != NULL) {
@@ -727,23 +616,25 @@ size_t uart_debug_write(uint8_t *data, uint32_t size)
       if (serial_debug.index >= UART_NUM) {
         return 0;
       }
-    }
-  }
-  obj = get_serial_obj(uart_handlers[serial_debug.index]);
-  if (!obj) {
-    return 0;
-  }
-
-  while (serial_tx_active(obj)) {
-    if ((HAL_GetTick() - tickstart) >= TX_TIMEOUT) {
-      return 0;
+    } else {
+      serial_t *obj = get_serial_obj(uart_handlers[serial_debug.index]);
+      if (obj) {
+        serial_debug.irq = obj->irq;
+      }
     }
   }
 
-  if (HAL_UART_Transmit(&(obj->handle), data, size, TX_TIMEOUT) != HAL_OK) {
-    size = 0;
+  HAL_NVIC_DisableIRQ(serial_debug.irq);
+
+  while (HAL_UART_Transmit(uart_handlers[serial_debug.index], data, size, TX_TIMEOUT) != HAL_OK) {
+    if ((HAL_GetTick() - tickstart) >=  TX_TIMEOUT) {
+      size = 0;
+      break;
+    }
   }
 
+  HAL_NVIC_EnableIRQ(serial_debug.irq);
+
   return size;
 }
 
@@ -975,14 +866,7 @@ void USART1_IRQHandler(void)
 void USART2_IRQHandler(void)
 {
   HAL_NVIC_ClearPendingIRQ(USART2_IRQn);
-  if (uart_handlers[UART2_INDEX] != NULL) {
-    HAL_UART_IRQHandler(uart_handlers[UART2_INDEX]);
-  }
-#if defined(STM32G0xx) && defined(LPUART2_BASE)
-  if (uart_handlers[LPUART2_INDEX] != NULL) {
-    HAL_UART_IRQHandler(uart_handlers[LPUART2_INDEX]);
-  }
-#endif
+  HAL_UART_IRQHandler(uart_handlers[UART2_INDEX]);
 }
 #endif
 
@@ -1023,7 +907,7 @@ void USART3_IRQHandler(void)
   if (uart_handlers[UART4_INDEX] != NULL) {
     HAL_UART_IRQHandler(uart_handlers[UART4_INDEX]);
   }
-#if defined(STM32F030xC) || defined(STM32G0xx) && (defined(LPUART2_BASE) || defined(USART5_BASE))
+#if defined(STM32F030xC)
   if (uart_handlers[UART5_INDEX] != NULL) {
     HAL_UART_IRQHandler(uart_handlers[UART5_INDEX]);
   }
@@ -1092,7 +976,7 @@ void UART5_IRQHandler(void)
   * @param  None
   * @retval None
   */
-#if defined(USART6_BASE) && !defined(STM32F0xx) && !defined(STM32G0xx)
+#if defined(USART6_BASE) && !defined(STM32F0xx)
 void USART6_IRQHandler(void)
 {
   HAL_NVIC_ClearPendingIRQ(USART6_IRQn);
