@@ -6,17 +6,6 @@
   *          functionalities of the ADC extension peripheral:
   *           + Extended features functions
   *
-  ******************************************************************************
-  * @attention
-  *
-  * Copyright (c) 2016 STMicroelectronics.
-  * All rights reserved.
-  *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
-  *
-  ******************************************************************************
   @verbatim
   ==============================================================================
                     ##### How to use this driver #####
@@ -80,7 +69,18 @@
        (+) Read the ADCs converted values using the HAL_ADCEx_MultiModeGetValue() function.
 
 
-  @endverbatim
+    @endverbatim
+  ******************************************************************************
+  * @attention
+  *
+  * <h2><center>&copy; Copyright (c) 2016 STMicroelectronics.
+  * All rights reserved.</center></h2>
+  *
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
+  *
   ******************************************************************************
   */
 
@@ -416,14 +416,10 @@ HAL_StatusTypeDef HAL_ADCEx_InjectedPollForConversion(ADC_HandleTypeDef* hadc, u
     {
       if((Timeout == 0U)||((HAL_GetTick() - tickstart ) > Timeout))
       {
-        /* New check to avoid false timeout detection in case of preemption */
-        if(!(__HAL_ADC_GET_FLAG(hadc, ADC_FLAG_JEOC)))
-        {
-          hadc->State= HAL_ADC_STATE_TIMEOUT;
-          /* Process unlocked */
-          __HAL_UNLOCK(hadc);
-          return HAL_TIMEOUT;
-        }
+        hadc->State= HAL_ADC_STATE_TIMEOUT;
+        /* Process unlocked */
+        __HAL_UNLOCK(hadc);
+        return HAL_TIMEOUT;
       }
     }
   }
@@ -1065,5 +1061,6 @@ static void ADC_MultiModeDMAError(DMA_HandleTypeDef *hdma)
 
 /**
   * @}
-  */
+  */ 
 
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
