@@ -6,12 +6,13 @@
   ******************************************************************************
   * @attention
   *
-  * Copyright (c) 2016 STMicroelectronics.
-  * All rights reserved.
+  * <h2><center>&copy; Copyright (c) 2016 STMicroelectronics.
+  * All rights reserved.</center></h2>
   *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
   *
   ******************************************************************************
   */
@@ -150,35 +151,35 @@ typedef enum
   */
 typedef struct __SMBUS_HandleTypeDef
 {
-  I2C_TypeDef                 *Instance;        /*!< SMBUS registers base address                            */
+  I2C_TypeDef                 *Instance;        /*!< SMBUS registers base address                  */
 
-  SMBUS_InitTypeDef             Init;           /*!< SMBUS communication parameters                          */
+  SMBUS_InitTypeDef             Init;           /*!< SMBUS communication parameters              */
 
-  uint8_t                       *pBuffPtr;      /*!< Pointer to SMBUS transfer buffer                        */
+  uint8_t                       *pBuffPtr;      /*!< Pointer to SMBUS transfer buffer            */
 
-  uint16_t                      XferSize;       /*!< SMBUS transfer size                                     */
+  uint16_t                      XferSize;       /*!< SMBUS transfer size                         */
 
-  __IO uint16_t                 XferCount;      /*!< SMBUS transfer counter                                  */
+  __IO uint16_t                 XferCount;      /*!< SMBUS transfer counter                      */
 
   __IO uint32_t                 XferOptions;    /*!< SMBUS transfer options this parameter can
-                                                     be a value of @ref SMBUS_XferOptions_definition         */
+                                                     be a value of @ref SMBUS_OPTIONS            */
 
   __IO uint32_t                 PreviousState;  /*!< SMBUS communication Previous state and mode
-                                                     context for internal usage                              */
+                                                     context for internal usage                  */
 
-  HAL_LockTypeDef               Lock;           /*!< SMBUS locking object                                    */
+  HAL_LockTypeDef               Lock;           /*!< SMBUS locking object                        */
 
-  __IO HAL_SMBUS_StateTypeDef   State;          /*!< SMBUS communication state                               */
+  __IO HAL_SMBUS_StateTypeDef   State;          /*!< SMBUS communication state                   */
 
-  __IO HAL_SMBUS_ModeTypeDef    Mode;           /*!< SMBUS communication mode                                */
+  __IO HAL_SMBUS_ModeTypeDef    Mode;           /*!< SMBUS communication mode                    */
 
-  __IO uint32_t                 ErrorCode;      /*!< SMBUS Error code                                        */
+  __IO uint32_t                 ErrorCode;      /*!< SMBUS Error code                            */
 
-  __IO uint32_t                 Devaddress;     /*!< SMBUS Target device address                             */
+  __IO uint32_t                 Devaddress;     /*!< SMBUS Target device address                 */
 
-  __IO uint32_t                 EventCount;     /*!< SMBUS Event counter                                     */
+  __IO uint32_t                 EventCount;     /*!< SMBUS Event counter                         */
 
-  uint8_t                       XferPEC;        /*!< SMBUS PEC data in reception mode                        */
+  uint8_t                       XferPEC;        /*!< SMBUS PEC data in reception mode            */
 
 #if (USE_HAL_SMBUS_REGISTER_CALLBACKS == 1)
   void (* MasterTxCpltCallback)(struct __SMBUS_HandleTypeDef *hsmbus);           /*!< SMBUS Master Tx Transfer completed callback */
@@ -604,10 +605,6 @@ void HAL_SMBUS_ListenCpltCallback(SMBUS_HandleTypeDef *hsmbus);
 void HAL_SMBUS_ErrorCallback(SMBUS_HandleTypeDef *hsmbus);
 void HAL_SMBUS_AbortCpltCallback(SMBUS_HandleTypeDef *hsmbus);
 
-/**
-  * @}
-  */
-
 /**
   * @}
   */
@@ -722,6 +719,10 @@ uint32_t HAL_SMBUS_GetError(SMBUS_HandleTypeDef *hsmbus);
   * @}
   */
 
+/**
+* @}
+*/
+
 #ifdef __cplusplus
 }
 #endif
@@ -729,3 +730,4 @@ uint32_t HAL_SMBUS_GetError(SMBUS_HandleTypeDef *hsmbus);
 
 #endif /* __STM32F4xx_HAL_SMBUS_H */
 
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
