@@ -6,17 +6,6 @@
   *          This file provides a generic firmware to drive SRAM memories
   *          mounted as external device.
   *
-  ******************************************************************************
-  * @attention
-  *
-  * Copyright (c) 2017 STMicroelectronics.
-  * All rights reserved.
-  *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
-  *
-  ******************************************************************************
   @verbatim
   ==============================================================================
                           ##### How to use this driver #####
@@ -75,25 +64,25 @@
       The compilation define  USE_HAL_SRAM_REGISTER_CALLBACKS when set to 1
       allows the user to configure dynamically the driver callbacks.
 
-      Use Functions HAL_SRAM_RegisterCallback() to register a user callback,
+      Use Functions @ref HAL_SRAM_RegisterCallback() to register a user callback,
       it allows to register following callbacks:
         (+) MspInitCallback    : SRAM MspInit.
         (+) MspDeInitCallback  : SRAM MspDeInit.
       This function takes as parameters the HAL peripheral handle, the Callback ID
       and a pointer to the user callback function.
 
-      Use function HAL_SRAM_UnRegisterCallback() to reset a callback to the default
+      Use function @ref HAL_SRAM_UnRegisterCallback() to reset a callback to the default
       weak (surcharged) function. It allows to reset following callbacks:
         (+) MspInitCallback    : SRAM MspInit.
         (+) MspDeInitCallback  : SRAM MspDeInit.
       This function) takes as parameters the HAL peripheral handle and the Callback ID.
 
-      By default, after the HAL_SRAM_Init and if the state is HAL_SRAM_STATE_RESET
+      By default, after the @ref HAL_SRAM_Init and if the state is HAL_SRAM_STATE_RESET
       all callbacks are reset to the corresponding legacy weak (surcharged) functions.
       Exception done for MspInit and MspDeInit callbacks that are respectively
-      reset to the legacy weak (surcharged) functions in the HAL_SRAM_Init
-      and  HAL_SRAM_DeInit only when these callbacks are null (not registered beforehand).
-      If not, MspInit or MspDeInit are not null, the HAL_SRAM_Init and HAL_SRAM_DeInit
+      reset to the legacy weak (surcharged) functions in the @ref HAL_SRAM_Init
+      and @ref  HAL_SRAM_DeInit only when these callbacks are null (not registered beforehand).
+      If not, MspInit or MspDeInit are not null, the @ref HAL_SRAM_Init and @ref HAL_SRAM_DeInit
       keep and use the user MspInit/MspDeInit callbacks (registered beforehand)
 
       Callbacks can be registered/unregistered in READY state only.
@@ -101,8 +90,8 @@
       in READY or RESET state, thus registered (user) MspInit/DeInit callbacks can be used
       during the Init/DeInit.
       In that case first register the MspInit/MspDeInit user callbacks
-      using HAL_SRAM_RegisterCallback before calling HAL_SRAM_DeInit
-      or HAL_SRAM_Init function.
+      using @ref HAL_SRAM_RegisterCallback before calling @ref HAL_SRAM_DeInit
+      or @ref HAL_SRAM_Init function.
 
       When The compilation define USE_HAL_SRAM_REGISTER_CALLBACKS is set to 0 or
       not defined, the callback registering feature is not available
@@ -110,32 +99,36 @@
 
   @endverbatim
   ******************************************************************************
+  * @attention
+  *
+  * <h2><center>&copy; Copyright (c) 2017 STMicroelectronics.
+  * All rights reserved.</center></h2>
+  *
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
+  *
+  ******************************************************************************
   */
 
 /* Includes ------------------------------------------------------------------*/
 #include "stm32f7xx_hal.h"
 
-
 /** @addtogroup STM32F7xx_HAL_Driver
   * @{
   */
 
-#ifdef HAL_SRAM_MODULE_ENABLED
-
 /** @defgroup SRAM SRAM
   * @brief SRAM driver modules
   * @{
   */
-
+#ifdef HAL_SRAM_MODULE_ENABLED
 /* Private typedef -----------------------------------------------------------*/
 /* Private define ------------------------------------------------------------*/
 /* Private macro -------------------------------------------------------------*/
 /* Private variables ---------------------------------------------------------*/
 /* Private function prototypes -----------------------------------------------*/
-static void SRAM_DMACplt(DMA_HandleTypeDef *hdma);
-static void SRAM_DMACpltProt(DMA_HandleTypeDef *hdma);
-static void SRAM_DMAError(DMA_HandleTypeDef *hdma);
-
 /* Exported functions --------------------------------------------------------*/
 
 /** @defgroup SRAM_Exported_Functions SRAM Exported Functions
@@ -164,22 +157,21 @@ static void SRAM_DMAError(DMA_HandleTypeDef *hdma);
   * @param  ExtTiming Pointer to SRAM extended mode timing structure
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Init(SRAM_HandleTypeDef *hsram, FMC_NORSRAM_TimingTypeDef *Timing,
-                                FMC_NORSRAM_TimingTypeDef *ExtTiming)
+HAL_StatusTypeDef HAL_SRAM_Init(SRAM_HandleTypeDef *hsram, FMC_NORSRAM_TimingTypeDef *Timing, FMC_NORSRAM_TimingTypeDef *ExtTiming)
 {
   /* Check the SRAM handle parameter */
-  if (hsram == NULL)
+  if(hsram == NULL)
   {
-    return HAL_ERROR;
+     return HAL_ERROR;
   }
 
-  if (hsram->State == HAL_SRAM_STATE_RESET)
+  if(hsram->State == HAL_SRAM_STATE_RESET)
   {
     /* Allocate lock resource and initialize it */
     hsram->Lock = HAL_UNLOCKED;
 
 #if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
-    if (hsram->MspInitCallback == NULL)
+    if(hsram->MspInitCallback == NULL)
     {
       hsram->MspInitCallback = HAL_SRAM_MspInit;
     }
@@ -191,25 +183,21 @@ HAL_StatusTypeDef HAL_SRAM_Init(SRAM_HandleTypeDef *hsram, FMC_NORSRAM_TimingTyp
 #else
     /* Initialize the low level hardware (MSP) */
     HAL_SRAM_MspInit(hsram);
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
+#endif
   }
 
   /* Initialize SRAM control Interface */
-  (void)FMC_NORSRAM_Init(hsram->Instance, &(hsram->Init));
+  FMC_NORSRAM_Init(hsram->Instance, &(hsram->Init));
 
   /* Initialize SRAM timing Interface */
-  (void)FMC_NORSRAM_Timing_Init(hsram->Instance, Timing, hsram->Init.NSBank);
+  FMC_NORSRAM_Timing_Init(hsram->Instance, Timing, hsram->Init.NSBank);
 
   /* Initialize SRAM extended mode timing Interface */
-  (void)FMC_NORSRAM_Extended_Timing_Init(hsram->Extended, ExtTiming, hsram->Init.NSBank,
-                                         hsram->Init.ExtendedMode);
+  FMC_NORSRAM_Extended_Timing_Init(hsram->Extended, ExtTiming, hsram->Init.NSBank,  hsram->Init.ExtendedMode);
 
   /* Enable the NORSRAM device */
   __FMC_NORSRAM_ENABLE(hsram->Instance, hsram->Init.NSBank);
 
-  /* Initialize the SRAM controller state */
-  hsram->State = HAL_SRAM_STATE_READY;
-
   return HAL_OK;
 }
 
@@ -222,7 +210,7 @@ HAL_StatusTypeDef HAL_SRAM_Init(SRAM_HandleTypeDef *hsram, FMC_NORSRAM_TimingTyp
 HAL_StatusTypeDef HAL_SRAM_DeInit(SRAM_HandleTypeDef *hsram)
 {
 #if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
-  if (hsram->MspDeInitCallback == NULL)
+  if(hsram->MspDeInitCallback == NULL)
   {
     hsram->MspDeInitCallback = HAL_SRAM_MspDeInit;
   }
@@ -232,12 +220,11 @@ HAL_StatusTypeDef HAL_SRAM_DeInit(SRAM_HandleTypeDef *hsram)
 #else
   /* De-Initialize the low level hardware (MSP) */
   HAL_SRAM_MspDeInit(hsram);
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
+#endif
 
   /* Configure the SRAM registers with their reset values */
-  (void)FMC_NORSRAM_DeInit(hsram->Instance, hsram->Extended, hsram->Init.NSBank);
+  FMC_NORSRAM_DeInit(hsram->Instance, hsram->Extended, hsram->Init.NSBank);
 
-  /* Reset the SRAM controller state */
   hsram->State = HAL_SRAM_STATE_RESET;
 
   /* Release Lock */
@@ -337,42 +324,30 @@ __weak void HAL_SRAM_DMA_XferErrorCallback(DMA_HandleTypeDef *hdma)
   * @param  BufferSize Size of the buffer to read from memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Read_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint8_t *pDstBuffer,
-                                   uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Read_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint8_t *pDstBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint8_t *psramaddress = (uint8_t *)pAddress;
-  uint8_t *pdestbuff = pDstBuffer;
-  HAL_SRAM_StateTypeDef state = hsram->State;
+  __IO uint8_t * psramaddress = (uint8_t *)pAddress;
 
-  /* Check the SRAM controller state */
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Read data from memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Read data from memory */
-    for (size = BufferSize; size != 0U; size--)
-    {
-      *pdestbuff = *psramaddress;
-      pdestbuff++;
-      psramaddress++;
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = state;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    return HAL_ERROR;
+    *pDstBuffer = *(__IO uint8_t *)psramaddress;
+    pDstBuffer++;
+    psramaddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -385,41 +360,36 @@ HAL_StatusTypeDef HAL_SRAM_Read_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress
   * @param  BufferSize Size of the buffer to write to memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Write_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint8_t *pSrcBuffer,
-                                    uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Write_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint8_t *pSrcBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint8_t *psramaddress = (uint8_t *)pAddress;
-  uint8_t *psrcbuff = pSrcBuffer;
+  __IO uint8_t * psramaddress = (uint8_t *)pAddress;
 
   /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_READY)
+  if(hsram->State == HAL_SRAM_STATE_PROTECTED)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Write data to memory */
-    for (size = BufferSize; size != 0U; size--)
-    {
-      *psramaddress = *psrcbuff;
-      psrcbuff++;
-      psramaddress++;
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_READY;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
+    return  HAL_ERROR;
   }
-  else
+
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Write data to memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    return HAL_ERROR;
+    *(__IO uint8_t *)psramaddress = *pSrcBuffer;
+    pSrcBuffer++;
+    psramaddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -432,54 +402,30 @@ HAL_StatusTypeDef HAL_SRAM_Write_8b(SRAM_HandleTypeDef *hsram, uint32_t *pAddres
   * @param  BufferSize Size of the buffer to read from memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Read_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint16_t *pDstBuffer,
-                                    uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Read_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint16_t *pDstBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint32_t *psramaddress = pAddress;
-  uint16_t *pdestbuff = pDstBuffer;
-  uint8_t limit;
-  HAL_SRAM_StateTypeDef state = hsram->State;
+  __IO uint16_t * psramaddress = (uint16_t *)pAddress;
 
-  /* Check the SRAM controller state */
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Read data from memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Check if the size is a 32-bits multiple */
-    limit = (((BufferSize % 2U) != 0U) ? 1U : 0U);
-
-    /* Read data from memory */
-    for (size = BufferSize; size != limit; size -= 2U)
-    {
-      *pdestbuff = (uint16_t)((*psramaddress) & 0x0000FFFFU);
-      pdestbuff++;
-      *pdestbuff = (uint16_t)(((*psramaddress) & 0xFFFF0000U) >> 16U);
-      pdestbuff++;
-      psramaddress++;
-    }
-
-    /* Read last 16-bits if size is not 32-bits multiple */
-    if (limit != 0U)
-    {
-      *pdestbuff = (uint16_t)((*psramaddress) & 0x0000FFFFU);
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = state;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    return HAL_ERROR;
+    *pDstBuffer = *(__IO uint16_t *)psramaddress;
+    pDstBuffer++;
+    psramaddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -492,53 +438,36 @@ HAL_StatusTypeDef HAL_SRAM_Read_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddres
   * @param  BufferSize Size of the buffer to write to memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Write_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint16_t *pSrcBuffer,
-                                     uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Write_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint16_t *pSrcBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint32_t *psramaddress = pAddress;
-  uint16_t *psrcbuff = pSrcBuffer;
-  uint8_t limit;
+  __IO uint16_t * psramaddress = (uint16_t *)pAddress;
 
   /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_READY)
+  if(hsram->State == HAL_SRAM_STATE_PROTECTED)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Check if the size is a 32-bits multiple */
-    limit = (((BufferSize % 2U) != 0U) ? 1U : 0U);
-
-    /* Write data to memory */
-    for (size = BufferSize; size != limit; size -= 2U)
-    {
-      *psramaddress = (uint32_t)(*psrcbuff);
-      psrcbuff++;
-      *psramaddress |= ((uint32_t)(*psrcbuff) << 16U);
-      psrcbuff++;
-      psramaddress++;
-    }
-
-    /* Write last 16-bits if size is not 32-bits multiple */
-    if (limit != 0U)
-    {
-      *psramaddress = ((uint32_t)(*psrcbuff) & 0x0000FFFFU) | ((*psramaddress) & 0xFFFF0000U);
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_READY;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
+    return  HAL_ERROR;
   }
-  else
+
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Write data to memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    return HAL_ERROR;
+    *(__IO uint16_t *)psramaddress = *pSrcBuffer;
+    pSrcBuffer++;
+    psramaddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -551,42 +480,28 @@ HAL_StatusTypeDef HAL_SRAM_Write_16b(SRAM_HandleTypeDef *hsram, uint32_t *pAddre
   * @param  BufferSize Size of the buffer to read from memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Read_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pDstBuffer,
-                                    uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Read_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pDstBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint32_t *psramaddress = pAddress;
-  uint32_t *pdestbuff = pDstBuffer;
-  HAL_SRAM_StateTypeDef state = hsram->State;
+  /* Process Locked */
+  __HAL_LOCK(hsram);
 
-  /* Check the SRAM controller state */
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Read data from memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Read data from memory */
-    for (size = BufferSize; size != 0U; size--)
-    {
-      *pdestbuff = *psramaddress;
-      pdestbuff++;
-      psramaddress++;
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = state;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    return HAL_ERROR;
+    *pDstBuffer = *(__IO uint32_t *)pAddress;
+    pDstBuffer++;
+    pAddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -599,41 +514,34 @@ HAL_StatusTypeDef HAL_SRAM_Read_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddres
   * @param  BufferSize Size of the buffer to write to memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Write_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pSrcBuffer,
-                                     uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Write_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pSrcBuffer, uint32_t BufferSize)
 {
-  uint32_t size;
-  __IO uint32_t *psramaddress = pAddress;
-  uint32_t *psrcbuff = pSrcBuffer;
-
   /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_READY)
+  if(hsram->State == HAL_SRAM_STATE_PROTECTED)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Write data to memory */
-    for (size = BufferSize; size != 0U; size--)
-    {
-      *psramaddress = *psrcbuff;
-      psrcbuff++;
-      psramaddress++;
-    }
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_READY;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
+    return  HAL_ERROR;
   }
-  else
+
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Write data to memory */
+  for(; BufferSize != 0; BufferSize--)
   {
-    return HAL_ERROR;
+    *(__IO uint32_t *)pAddress = *pSrcBuffer;
+    pSrcBuffer++;
+    pAddress++;
   }
 
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
   return HAL_OK;
 }
 
@@ -646,44 +554,28 @@ HAL_StatusTypeDef HAL_SRAM_Write_32b(SRAM_HandleTypeDef *hsram, uint32_t *pAddre
   * @param  BufferSize Size of the buffer to read from memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Read_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pDstBuffer,
-                                    uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Read_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pDstBuffer, uint32_t BufferSize)
 {
-  HAL_StatusTypeDef status;
-  HAL_SRAM_StateTypeDef state = hsram->State;
+  /* Process Locked */
+  __HAL_LOCK(hsram);
 
-  /* Check the SRAM controller state */
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
-  {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
 
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
+  /* Configure DMA user callbacks */
+  hsram->hdma->XferCpltCallback  = HAL_SRAM_DMA_XferCpltCallback;
+  hsram->hdma->XferErrorCallback = HAL_SRAM_DMA_XferErrorCallback;
 
-    /* Configure DMA user callbacks */
-    if (state == HAL_SRAM_STATE_READY)
-    {
-      hsram->hdma->XferCpltCallback = SRAM_DMACplt;
-    }
-    else
-    {
-      hsram->hdma->XferCpltCallback = SRAM_DMACpltProt;
-    }
-    hsram->hdma->XferErrorCallback = SRAM_DMAError;
+  /* Enable the DMA Stream */
+  HAL_DMA_Start_IT(hsram->hdma, (uint32_t)pAddress, (uint32_t)pDstBuffer, (uint32_t)BufferSize);
 
-    /* Enable the DMA Stream */
-    status = HAL_DMA_Start_IT(hsram->hdma, (uint32_t)pAddress, (uint32_t)pDstBuffer, (uint32_t)BufferSize);
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
 
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    status = HAL_ERROR;
-  }
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
 
-  return status;
+  return HAL_OK;
 }
 
 /**
@@ -695,36 +587,34 @@ HAL_StatusTypeDef HAL_SRAM_Read_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddres
   * @param  BufferSize Size of the buffer to write to memory
   * @retval HAL status
   */
-HAL_StatusTypeDef HAL_SRAM_Write_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pSrcBuffer,
-                                     uint32_t BufferSize)
+HAL_StatusTypeDef HAL_SRAM_Write_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddress, uint32_t *pSrcBuffer, uint32_t BufferSize)
 {
-  HAL_StatusTypeDef status;
-
   /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_READY)
+  if(hsram->State == HAL_SRAM_STATE_PROTECTED)
   {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
-
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
-
-    /* Configure DMA user callbacks */
-    hsram->hdma->XferCpltCallback = SRAM_DMACplt;
-    hsram->hdma->XferErrorCallback = SRAM_DMAError;
-
-    /* Enable the DMA Stream */
-    status = HAL_DMA_Start_IT(hsram->hdma, (uint32_t)pSrcBuffer, (uint32_t)pAddress, (uint32_t)BufferSize);
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    status = HAL_ERROR;
+    return  HAL_ERROR;
   }
 
-  return status;
+  /* Process Locked */
+  __HAL_LOCK(hsram);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
+
+  /* Configure DMA user callbacks */
+  hsram->hdma->XferCpltCallback  = HAL_SRAM_DMA_XferCpltCallback;
+  hsram->hdma->XferErrorCallback = HAL_SRAM_DMA_XferErrorCallback;
+
+  /* Enable the DMA Stream */
+  HAL_DMA_Start_IT(hsram->hdma, (uint32_t)pSrcBuffer, (uint32_t)pAddress, (uint32_t)BufferSize);
+
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
+
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
+
+  return HAL_OK;
 }
 
 #if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
@@ -739,13 +629,12 @@ HAL_StatusTypeDef HAL_SRAM_Write_DMA(SRAM_HandleTypeDef *hsram, uint32_t *pAddre
   * @param pCallback : pointer to the Callback function
   * @retval status
   */
-HAL_StatusTypeDef HAL_SRAM_RegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId,
-                                            pSRAM_CallbackTypeDef pCallback)
+HAL_StatusTypeDef HAL_SRAM_RegisterCallback (SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId, pSRAM_CallbackTypeDef pCallback)
 {
   HAL_StatusTypeDef status = HAL_OK;
   HAL_SRAM_StateTypeDef state;
 
-  if (pCallback == NULL)
+  if(pCallback == NULL)
   {
     return HAL_ERROR;
   }
@@ -754,20 +643,20 @@ HAL_StatusTypeDef HAL_SRAM_RegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_
   __HAL_LOCK(hsram);
 
   state = hsram->State;
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_RESET) || (state == HAL_SRAM_STATE_PROTECTED))
+  if((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_RESET) || (state == HAL_SRAM_STATE_PROTECTED))
   {
     switch (CallbackId)
     {
-      case HAL_SRAM_MSP_INIT_CB_ID :
-        hsram->MspInitCallback = pCallback;
-        break;
-      case HAL_SRAM_MSP_DEINIT_CB_ID :
-        hsram->MspDeInitCallback = pCallback;
-        break;
-      default :
-        /* update return status */
-        status =  HAL_ERROR;
-        break;
+    case HAL_SRAM_MSP_INIT_CB_ID :
+      hsram->MspInitCallback = pCallback;
+      break;
+    case HAL_SRAM_MSP_DEINIT_CB_ID :
+      hsram->MspDeInitCallback = pCallback;
+      break;
+    default :
+      /* update return status */
+      status =  HAL_ERROR;
+      break;
     }
   }
   else
@@ -793,7 +682,7 @@ HAL_StatusTypeDef HAL_SRAM_RegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_
   *          @arg @ref HAL_SRAM_DMA_XFER_ERR_CB_ID   SRAM DMA Xfer Error callback ID
   * @retval status
   */
-HAL_StatusTypeDef HAL_SRAM_UnRegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId)
+HAL_StatusTypeDef HAL_SRAM_UnRegisterCallback (SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId)
 {
   HAL_StatusTypeDef status = HAL_OK;
   HAL_SRAM_StateTypeDef state;
@@ -802,42 +691,42 @@ HAL_StatusTypeDef HAL_SRAM_UnRegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRA
   __HAL_LOCK(hsram);
 
   state = hsram->State;
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
+  if((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
   {
     switch (CallbackId)
     {
-      case HAL_SRAM_MSP_INIT_CB_ID :
-        hsram->MspInitCallback = HAL_SRAM_MspInit;
-        break;
-      case HAL_SRAM_MSP_DEINIT_CB_ID :
-        hsram->MspDeInitCallback = HAL_SRAM_MspDeInit;
-        break;
-      case HAL_SRAM_DMA_XFER_CPLT_CB_ID :
-        hsram->DmaXferCpltCallback = HAL_SRAM_DMA_XferCpltCallback;
-        break;
-      case HAL_SRAM_DMA_XFER_ERR_CB_ID :
-        hsram->DmaXferErrorCallback = HAL_SRAM_DMA_XferErrorCallback;
-        break;
-      default :
-        /* update return status */
-        status =  HAL_ERROR;
-        break;
+    case HAL_SRAM_MSP_INIT_CB_ID :
+      hsram->MspInitCallback = HAL_SRAM_MspInit;
+      break;
+    case HAL_SRAM_MSP_DEINIT_CB_ID :
+      hsram->MspDeInitCallback = HAL_SRAM_MspDeInit;
+      break;
+    case HAL_SRAM_DMA_XFER_CPLT_CB_ID :
+      hsram->DmaXferCpltCallback = HAL_SRAM_DMA_XferCpltCallback;
+      break;
+    case HAL_SRAM_DMA_XFER_ERR_CB_ID :
+      hsram->DmaXferErrorCallback = HAL_SRAM_DMA_XferErrorCallback;
+      break;
+    default :
+      /* update return status */
+      status =  HAL_ERROR;
+      break;
     }
   }
-  else if (state == HAL_SRAM_STATE_RESET)
+  else if(state == HAL_SRAM_STATE_RESET)
   {
     switch (CallbackId)
     {
-      case HAL_SRAM_MSP_INIT_CB_ID :
-        hsram->MspInitCallback = HAL_SRAM_MspInit;
-        break;
-      case HAL_SRAM_MSP_DEINIT_CB_ID :
-        hsram->MspDeInitCallback = HAL_SRAM_MspDeInit;
-        break;
-      default :
-        /* update return status */
-        status =  HAL_ERROR;
-        break;
+    case HAL_SRAM_MSP_INIT_CB_ID :
+      hsram->MspInitCallback = HAL_SRAM_MspInit;
+      break;
+    case HAL_SRAM_MSP_DEINIT_CB_ID :
+      hsram->MspDeInitCallback = HAL_SRAM_MspDeInit;
+      break;
+    default :
+      /* update return status */
+      status =  HAL_ERROR;
+      break;
     }
   }
   else
@@ -862,13 +751,12 @@ HAL_StatusTypeDef HAL_SRAM_UnRegisterCallback(SRAM_HandleTypeDef *hsram, HAL_SRA
   * @param pCallback : pointer to the Callback function
   * @retval status
   */
-HAL_StatusTypeDef HAL_SRAM_RegisterDmaCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId,
-                                               pSRAM_DmaCallbackTypeDef pCallback)
+HAL_StatusTypeDef HAL_SRAM_RegisterDmaCallback(SRAM_HandleTypeDef *hsram, HAL_SRAM_CallbackIDTypeDef CallbackId, pSRAM_DmaCallbackTypeDef pCallback)
 {
   HAL_StatusTypeDef status = HAL_OK;
   HAL_SRAM_StateTypeDef state;
 
-  if (pCallback == NULL)
+  if(pCallback == NULL)
   {
     return HAL_ERROR;
   }
@@ -877,20 +765,20 @@ HAL_StatusTypeDef HAL_SRAM_RegisterDmaCallback(SRAM_HandleTypeDef *hsram, HAL_SR
   __HAL_LOCK(hsram);
 
   state = hsram->State;
-  if ((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
+  if((state == HAL_SRAM_STATE_READY) || (state == HAL_SRAM_STATE_PROTECTED))
   {
     switch (CallbackId)
     {
-      case HAL_SRAM_DMA_XFER_CPLT_CB_ID :
-        hsram->DmaXferCpltCallback = pCallback;
-        break;
-      case HAL_SRAM_DMA_XFER_ERR_CB_ID :
-        hsram->DmaXferErrorCallback = pCallback;
-        break;
-      default :
-        /* update return status */
-        status =  HAL_ERROR;
-        break;
+    case HAL_SRAM_DMA_XFER_CPLT_CB_ID :
+      hsram->DmaXferCpltCallback = pCallback;
+      break;
+    case HAL_SRAM_DMA_XFER_ERR_CB_ID :
+      hsram->DmaXferErrorCallback = pCallback;
+      break;
+    default :
+      /* update return status */
+      status =  HAL_ERROR;
+      break;
     }
   }
   else
@@ -903,15 +791,14 @@ HAL_StatusTypeDef HAL_SRAM_RegisterDmaCallback(SRAM_HandleTypeDef *hsram, HAL_SR
   __HAL_UNLOCK(hsram);
   return status;
 }
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
-
+#endif
 /**
   * @}
   */
 
 /** @defgroup SRAM_Exported_Functions_Group3 Control functions
-  *  @brief   Control functions
-  *
+ *  @brief   Control functions
+ *
 @verbatim
   ==============================================================================
                         ##### SRAM Control functions #####
@@ -932,28 +819,17 @@ HAL_StatusTypeDef HAL_SRAM_RegisterDmaCallback(SRAM_HandleTypeDef *hsram, HAL_SR
   */
 HAL_StatusTypeDef HAL_SRAM_WriteOperation_Enable(SRAM_HandleTypeDef *hsram)
 {
-  /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_PROTECTED)
-  {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
+  /* Process Locked */
+  __HAL_LOCK(hsram);
 
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
+  /* Enable write operation */
+  FMC_NORSRAM_WriteOperation_Enable(hsram->Instance, hsram->Init.NSBank);
 
-    /* Enable write operation */
-    (void)FMC_NORSRAM_WriteOperation_Enable(hsram->Instance, hsram->Init.NSBank);
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_READY;
 
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_READY;
-
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    return HAL_ERROR;
-  }
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
 
   return HAL_OK;
 }
@@ -966,28 +842,20 @@ HAL_StatusTypeDef HAL_SRAM_WriteOperation_Enable(SRAM_HandleTypeDef *hsram)
   */
 HAL_StatusTypeDef HAL_SRAM_WriteOperation_Disable(SRAM_HandleTypeDef *hsram)
 {
-  /* Check the SRAM controller state */
-  if (hsram->State == HAL_SRAM_STATE_READY)
-  {
-    /* Process Locked */
-    __HAL_LOCK(hsram);
+  /* Process Locked */
+  __HAL_LOCK(hsram);
 
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_BUSY;
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_BUSY;
 
-    /* Disable write operation */
-    (void)FMC_NORSRAM_WriteOperation_Disable(hsram->Instance, hsram->Init.NSBank);
+  /* Disable write operation */
+  FMC_NORSRAM_WriteOperation_Disable(hsram->Instance, hsram->Init.NSBank);
 
-    /* Update the SRAM controller state */
-    hsram->State = HAL_SRAM_STATE_PROTECTED;
+  /* Update the SRAM controller state */
+  hsram->State = HAL_SRAM_STATE_PROTECTED;
 
-    /* Process unlocked */
-    __HAL_UNLOCK(hsram);
-  }
-  else
-  {
-    return HAL_ERROR;
-  }
+  /* Process unlocked */
+  __HAL_UNLOCK(hsram);
 
   return HAL_OK;
 }
@@ -997,8 +865,8 @@ HAL_StatusTypeDef HAL_SRAM_WriteOperation_Disable(SRAM_HandleTypeDef *hsram)
   */
 
 /** @defgroup SRAM_Exported_Functions_Group4 Peripheral State functions
-  *  @brief   Peripheral State functions
-  *
+ *  @brief   Peripheral State functions
+ *
 @verbatim
   ==============================================================================
                       ##### SRAM State functions #####
@@ -1029,80 +897,13 @@ HAL_SRAM_StateTypeDef HAL_SRAM_GetState(SRAM_HandleTypeDef *hsram)
 /**
   * @}
   */
-
-/**
-  * @brief  DMA SRAM process complete callback.
-  * @param  hdma : DMA handle
-  * @retval None
-  */
-static void SRAM_DMACplt(DMA_HandleTypeDef *hdma)
-{
-  SRAM_HandleTypeDef *hsram = (SRAM_HandleTypeDef *)(hdma->Parent);
-
-  /* Disable the DMA channel */
-  __HAL_DMA_DISABLE(hdma);
-
-  /* Update the SRAM controller state */
-  hsram->State = HAL_SRAM_STATE_READY;
-
-#if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
-  hsram->DmaXferCpltCallback(hdma);
-#else
-  HAL_SRAM_DMA_XferCpltCallback(hdma);
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
-}
-
-/**
-  * @brief  DMA SRAM process complete callback.
-  * @param  hdma : DMA handle
-  * @retval None
-  */
-static void SRAM_DMACpltProt(DMA_HandleTypeDef *hdma)
-{
-  SRAM_HandleTypeDef *hsram = (SRAM_HandleTypeDef *)(hdma->Parent);
-
-  /* Disable the DMA channel */
-  __HAL_DMA_DISABLE(hdma);
-
-  /* Update the SRAM controller state */
-  hsram->State = HAL_SRAM_STATE_PROTECTED;
-
-#if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
-  hsram->DmaXferCpltCallback(hdma);
-#else
-  HAL_SRAM_DMA_XferCpltCallback(hdma);
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
-}
-
-/**
-  * @brief  DMA SRAM error callback.
-  * @param  hdma : DMA handle
-  * @retval None
-  */
-static void SRAM_DMAError(DMA_HandleTypeDef *hdma)
-{
-  SRAM_HandleTypeDef *hsram = (SRAM_HandleTypeDef *)(hdma->Parent);
-
-  /* Disable the DMA channel */
-  __HAL_DMA_DISABLE(hdma);
-
-  /* Update the SRAM controller state */
-  hsram->State = HAL_SRAM_STATE_ERROR;
-
-#if (USE_HAL_SRAM_REGISTER_CALLBACKS == 1)
-  hsram->DmaXferErrorCallback(hdma);
-#else
-  HAL_SRAM_DMA_XferErrorCallback(hdma);
-#endif /* USE_HAL_SRAM_REGISTER_CALLBACKS */
-}
-
-/**
-  * @}
-  */
-
 #endif /* HAL_SRAM_MODULE_ENABLED */
+/**
+  * @}
+  */
 
 /**
   * @}
   */
 
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
