@@ -5,17 +5,6 @@
   * @brief   HAL module driver.
   *          This is the common part of the HAL initialization
   *
-  ******************************************************************************
-  * @attention
-  *
-  * Copyright (c) 2018 STMicroelectronics.
-  * All rights reserved.
-  *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
-  *
-  ******************************************************************************
   @verbatim
   ==============================================================================
                      ##### How to use this driver #####
@@ -30,6 +19,17 @@
 
   @endverbatim
   ******************************************************************************
+  * @attention
+  *
+  * <h2><center>&copy; Copyright (c) 2018 STMicroelectronics.
+  * All rights reserved.</center></h2>
+  *
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
+  *
+  ******************************************************************************
   */
 
 /* Includes ------------------------------------------------------------------*/
@@ -53,11 +53,11 @@
   * @{
   */
 /**
-  * @brief STM32G0xx HAL Driver version number
-  */
+ * @brief STM32G0xx HAL Driver version number
+   */
 #define __STM32G0xx_HAL_VERSION_MAIN   (0x01U) /*!< [31:24] main version */
-#define __STM32G0xx_HAL_VERSION_SUB1   (0x04U) /*!< [23:16] sub1 version */
-#define __STM32G0xx_HAL_VERSION_SUB2   (0x05U) /*!< [15:8]  sub2 version */
+#define __STM32G0xx_HAL_VERSION_SUB1   (0x03U) /*!< [23:16] sub1 version */
+#define __STM32G0xx_HAL_VERSION_SUB2   (0x00U) /*!< [15:8]  sub2 version */
 #define __STM32G0xx_HAL_VERSION_RC     (0x00U) /*!< [7:0]  release candidate */
 #define __STM32G0xx_HAL_VERSION         ((__STM32G0xx_HAL_VERSION_MAIN << 24U)\
                                         |(__STM32G0xx_HAL_VERSION_SUB1 << 16U)\
@@ -79,7 +79,7 @@
   */
 __IO uint32_t uwTick;
 uint32_t uwTickPrio = (1UL << __NVIC_PRIO_BITS); /* Invalid PRIO */
-HAL_TickFreqTypeDef uwTickFreq = HAL_TICK_FREQ_DEFAULT;  /* 1KHz */
+uint32_t uwTickFreq = HAL_TICK_FREQ_DEFAULT;  /* 1KHz */
 /**
   * @}
   */
@@ -241,11 +241,10 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
 {
   HAL_StatusTypeDef  status = HAL_OK;
 
-  /* Check uwTickFreq for MisraC 2012 (even if uwTickFreq is a enum type that doesn't take the value zero)*/
-  if ((uint32_t)uwTickFreq != 0U)
+  if (uwTickFreq != 0U)
   {
     /*Configure the SysTick to have interrupt in 1ms time basis*/
-    if (HAL_SYSTICK_Config(SystemCoreClock / (1000U /(uint32_t)uwTickFreq)) == 0U)
+    if (HAL_SYSTICK_Config(SystemCoreClock / (1000U /uwTickFreq)) == 0U)
     {
       /* Configure the SysTick IRQ priority */
       if (TickPriority < (1UL << __NVIC_PRIO_BITS))
@@ -307,7 +306,7 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
   */
 __weak void HAL_IncTick(void)
 {
-  uwTick += (uint32_t)uwTickFreq;
+  uwTick += uwTickFreq;
 }
 
 /**
@@ -334,26 +333,18 @@ uint32_t HAL_GetTickPrio(void)
   * @brief Set new tick Freq.
   * @retval status
   */
-HAL_StatusTypeDef HAL_SetTickFreq(HAL_TickFreqTypeDef Freq)
+HAL_StatusTypeDef HAL_SetTickFreq(uint32_t Freq)
 {
   HAL_StatusTypeDef status  = HAL_OK;
-  HAL_TickFreqTypeDef prevTickFreq;
   assert_param(IS_TICKFREQ(Freq));
 
   if (uwTickFreq != Freq)
   {
-    /* Back up uwTickFreq frequency */
-    prevTickFreq = uwTickFreq;
-
-    /* Update uwTickFreq global variable used by HAL_InitTick() */
-    uwTickFreq = Freq;
-
     /* Apply the new tick Freq  */
     status = HAL_InitTick(uwTickPrio);
-    if (status != HAL_OK)
+    if (status == HAL_OK)
     {
-      /* Restore previous tick frequency */
-      uwTickFreq = prevTickFreq;
+      uwTickFreq = Freq;
     }
   }
 
@@ -364,7 +355,7 @@ HAL_StatusTypeDef HAL_SetTickFreq(HAL_TickFreqTypeDef Freq)
   * @brief return tick frequency.
   * @retval tick period in Hz
   */
-HAL_TickFreqTypeDef HAL_GetTickFreq(void)
+uint32_t HAL_GetTickFreq(void)
 {
   return uwTickFreq;
 }
@@ -593,11 +584,6 @@ void HAL_SYSCFG_VREFBUF_HighImpedanceConfig(uint32_t Mode)
 
 /**
   * @brief  Tune the Internal Voltage Reference buffer (VREFBUF).
-  * @note   VrefBuf voltage scale is calibrated in production for each device,
-  *         using voltage scale 1. This calibration value is loaded
-  *         as default trimming value at device power up.
-  *         This trimming value can be fine tuned for voltage scales 0 and 1
-  *         using this function.
   * @retval None
   */
 void HAL_SYSCFG_VREFBUF_TrimmingConfig(uint32_t TrimmingValue)
@@ -692,7 +678,7 @@ void HAL_SYSCFG_DisableRemap(uint32_t PinRemap)
   CLEAR_BIT(SYSCFG->CFGR1, PinRemap);
 }
 
-#if defined(SYSCFG_CDEN_SUPPORT)
+#if defined(STM32G041xx) || defined(STM32G031xx) || defined(STM32G030xx)
 /**
   * @brief  Enable Clamping Diode on specified IO
   * @param  PinConfig specifies on which pins clamping Diode has to be enabled
@@ -720,7 +706,7 @@ void HAL_SYSCFG_DisableClampingDiode(uint32_t PinConfig)
   assert_param(IS_SYSCFG_CLAMPINGDIODE(PinConfig));
   CLEAR_BIT(SYSCFG->CFGR2, PinConfig);
 }
-#endif /* SYSCFG_CDEN_SUPPORT */
+#endif
 
 #if defined (SYSCFG_CFGR1_UCPD1_STROBE) || defined (SYSCFG_CFGR1_UCPD2_STROBE)
 /**
@@ -756,3 +742,4 @@ void HAL_SYSCFG_StrobeDBattpinsConfig(uint32_t ConfigDeadBattery)
   * @}
   */
 
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
