@@ -68,12 +68,13 @@
   ******************************************************************************
   * @attention
   *
-  * Copyright (c) 2016 STMicroelectronics.
-  * All rights reserved.
+  * <h2><center>&copy; Copyright(c) 2016 STMicroelectronics.
+  * All rights reserved.</center></h2>
   *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
   *
   ******************************************************************************
   */
@@ -295,7 +296,7 @@ __weak void HAL_CRYP_MspDeInit(CRYP_HandleTypeDef *hcryp)
   ==============================================================================
     [..]  This section provides functions allowing to:
       (+) Encrypt plaintext using AES algorithm in different chaining modes
-      (+) Decrypt ciphertext using AES algorithm in different chaining modes
+      (+) Decrypt cyphertext using AES algorithm in different chaining modes
     [..]  Three processing functions are available:
       (+) Polling mode
       (+) Interrupt mode
@@ -312,7 +313,7 @@ __weak void HAL_CRYP_MspDeInit(CRYP_HandleTypeDef *hcryp)
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
   * @retval HAL status
   */
@@ -322,7 +323,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 and Size multiple of 16*/
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -388,7 +389,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
   * @retval HAL status
   */
@@ -398,7 +399,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -467,7 +468,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
   * @retval HAL status
   */
@@ -477,7 +478,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -544,7 +545,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pP
   *         then decrypted pCypherData. The cypher data are available in pPlainData
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
@@ -556,7 +557,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -620,7 +621,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   *         then decrypted pCypherData. The cypher data are available in pPlainData
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
@@ -632,7 +633,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -699,7 +700,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   *         then decrypted pCypherData. The cypher data are available in pPlainData
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Timeout Specify Timeout value
@@ -711,7 +712,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   __HAL_LOCK(hcryp);
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -767,7 +768,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt(CRYP_HandleTypeDef *hcryp, uint8_t *pC
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -775,7 +776,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -820,7 +821,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -853,7 +854,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -861,7 +862,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -909,7 +910,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -942,7 +943,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -950,7 +951,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -998,7 +999,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -1029,7 +1030,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES ECB decryption mode using Interrupt.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1039,7 +1040,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1084,7 +1085,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -1115,7 +1116,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES CBC decryption mode using IT.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1125,7 +1126,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1173,7 +1174,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -1204,7 +1205,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES CTR decryption mode using Interrupt.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1214,7 +1215,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1262,7 +1263,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
     /* Enable CRYP */
     __HAL_CRYP_ENABLE(hcryp);
 
-    /* Get the last input data address */
+    /* Get the last input data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -1295,7 +1296,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt_IT(CRYP_HandleTypeDef *hcryp, uint8_t
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -1303,7 +1304,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1360,7 +1361,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -1368,7 +1369,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1428,7 +1429,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   *         the configuration information for CRYP module
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16.
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @retval HAL status
   */
 HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t *pPlainData, uint16_t Size, uint8_t *pCypherData)
@@ -1436,7 +1437,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1495,7 +1496,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Encrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES ECB decryption mode using DMA.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1505,7 +1506,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1564,7 +1565,7 @@ HAL_StatusTypeDef HAL_CRYP_AESECB_Decrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES CBC encryption mode using DMA.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16 bytes
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1574,7 +1575,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1636,7 +1637,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCBC_Decrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   * @brief  Initializes the CRYP peripheral in AES CTR decryption mode using DMA.
   * @param  hcryp pointer to a CRYP_HandleTypeDef structure that contains
   *         the configuration information for CRYP module
-  * @param  pCypherData Pointer to the ciphertext buffer (aligned on u32)
+  * @param  pCypherData Pointer to the cyphertext buffer (aligned on u32)
   * @param  Size Length of the plaintext buffer, must be a multiple of 16
   * @param  pPlainData Pointer to the plaintext buffer (aligned on u32)
   * @retval HAL status
@@ -1646,7 +1647,7 @@ HAL_StatusTypeDef HAL_CRYP_AESCTR_Decrypt_DMA(CRYP_HandleTypeDef *hcryp, uint8_t
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
   /* Check that data aligned on u32 */
-  if((((uint32_t)pPlainData & 0x00000003UL) != 0U) || (((uint32_t)pCypherData & 0x00000003UL) != 0U) || ((Size & 0x000FU) != 0U))
+  if((((uint32_t)pPlainData & (uint32_t)0x00000003U) != 0U) || (((uint32_t)pCypherData & (uint32_t)0x00000003U) != 0U) || ((Size & (uint16_t)0x000FU) != 0U))
   {
     /* Process Locked */
     __HAL_UNLOCK(hcryp);
@@ -1886,7 +1887,7 @@ static HAL_StatusTypeDef CRYP_EncryptDecrypt_IT(CRYP_HandleTypeDef *hcryp)
 {
   uint32_t inputaddr = 0U, outputaddr = 0U;
 
-  /* Get the last Output data address */
+  /* Get the last Output data adress */
   outputaddr = (uint32_t)hcryp->pCrypOutBuffPtr;
 
   /* Read the Output block from the Output Register */
@@ -1919,7 +1920,7 @@ static HAL_StatusTypeDef CRYP_EncryptDecrypt_IT(CRYP_HandleTypeDef *hcryp)
   }
   else /* Process the rest of input text */
   {
-    /* Get the last Input data address */
+    /* Get the last Intput data adress */
     inputaddr = (uint32_t)hcryp->pCrypInBuffPtr;
 
     /* Write the Input block in the Data Input register */
@@ -2156,3 +2157,5 @@ static void CRYP_SetDMAConfig(CRYP_HandleTypeDef *hcryp, uint32_t inputaddr, uin
 
 #endif /* HAL_CRYP_MODULE_ENABLED */
 #endif /* STM32L021xx || STM32L041xx || STM32L062xx || STM32L063xx || STM32L081xx || STM32L082xx || STM32L083xx */
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
+
