@@ -6,12 +6,13 @@
   ******************************************************************************
   * @attention
   *
-  * Copyright (c) 2019 STMicroelectronics.
-  * All rights reserved.
+  * <h2><center>&copy; Copyright (c) 2019 STMicroelectronics.
+  * All rights reserved.</center></h2>
   *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
   *
   ******************************************************************************
   */
@@ -98,39 +99,37 @@ typedef struct
   */
 typedef struct
 {
-  LPTIM_ClockConfigTypeDef     Clock;             /*!< Specifies the clock parameters */
+  LPTIM_ClockConfigTypeDef     Clock;               /*!< Specifies the clock parameters */
 
-  LPTIM_ULPClockConfigTypeDef  UltraLowPowerClock;/*!< Specifies the Ultra Low Power clock parameters */
+  LPTIM_ULPClockConfigTypeDef  UltraLowPowerClock;  /*!< Specifies the Ultra Low Power clock parameters */
 
-  LPTIM_TriggerConfigTypeDef   Trigger;           /*!< Specifies the Trigger parameters */
+  LPTIM_TriggerConfigTypeDef   Trigger;             /*!< Specifies the Trigger parameters */
 
-  uint32_t                     OutputPolarity;    /*!< Specifies the Output polarity.
-                                                  This parameter can be a value of @ref LPTIM_Output_Polarity */
+  uint32_t                     OutputPolarity;      /*!< Specifies the Output polarity.
+                                                    This parameter can be a value of @ref LPTIM_Output_Polarity */
 
-  uint32_t                     UpdateMode;        /*!< Specifies whether the update of the autoreload and the compare
-                                                  values is done immediately or after the end of current period.
-                                                  This parameter can be a value of @ref LPTIM_Updating_Mode */
+  uint32_t                     UpdateMode;          /*!< Specifies whether the update of the autoreload and the compare
+                                                    values is done immediately or after the end of current period.
+                                                    This parameter can be a value of @ref LPTIM_Updating_Mode */
 
-  uint32_t                     CounterSource;     /*!< Specifies whether the counter is incremented each internal event
-                                                  or each external event.
-                                                  This parameter can be a value of @ref LPTIM_Counter_Source */
+  uint32_t                     CounterSource;       /*!< Specifies whether the counter is incremented each internal event
+                                                    or each external event.
+                                                    This parameter can be a value of @ref LPTIM_Counter_Source */
 
-  uint32_t                     Input1Source;      /*!< Specifies source selected for input1 (GPIO or comparator output).
-                                                  This parameter can be a value of @ref LPTIM_Input1_Source */
+  uint32_t                     Input1Source;        /*!< Specifies source selected for input1 (GPIO or comparator output).
+                                                    This parameter can be a value of @ref LPTIM_Input1_Source */
 
-  uint32_t                     Input2Source;      /*!< Specifies source selected for input2 (GPIO or comparator output).
-                                                  Note: This parameter is used only for encoder feature so is used only
-                                                  for LPTIM1 instance.
-                                                  This parameter can be a value of @ref LPTIM_Input2_Source */
+  uint32_t                     Input2Source;        /*!< Specifies source selected for input2 (GPIO or comparator output).
+                                                    Note: This parameter is used only for encoder feature so is used only
+                                                    for LPTIM1 instance.
+                                                    This parameter can be a value of @ref LPTIM_Input2_Source */
 
-  uint32_t                     RepetitionCounter;/*!< Specifies the repetition counter value.
-                                                  Each time the RCR downcounter reaches zero, an update event is
-                                                  generated and counting restarts from the RCR value (N).
-                                                  Note: When using repetition counter the UpdateMode field must be
-                                                        set to LPTIM_UPDATE_ENDOFPERIOD otherwise unpredictable
-                                                        behavior may occur.
-                                                  This parameter must be a number between Min_Data = 0x00 and
-                                                  Max_Data = 0xFF. */
+  uint32_t                     RepetitionCounter;  /*!< Specifies the repetition counter value. Each time the RCR downcounter
+                                                    reaches zero, an update event is generated and counting restarts
+                                                    from the RCR value (N).
+                                                    Note: When using repetition counter the UpdateMode field must be set to
+                                                          LPTIM_UPDATE_ENDOFPERIOD otherwise unpredictable behavior may occur.
+                                                    This parameter must be a number between Min_Data = 0x00 and Max_Data = 0xFF. */
 } LPTIM_InitTypeDef;
 
 /**
@@ -590,6 +589,7 @@ typedef  void (*pLPTIM_CallbackTypeDef)(LPTIM_HandleTypeDef *hlptim);  /*!< poin
 #define __HAL_LPTIM_LPTIM1_EXTI_DISABLE_IT()           (EXTI->IMR2\
                                                         &= ~(LPTIM_EXTI_LINE_LPTIM1))
 
+
 /**
   * @brief  Enable the LPTIM1 EXTI line in event mode.
   * @retval None
@@ -616,6 +616,7 @@ typedef  void (*pLPTIM_CallbackTypeDef)(LPTIM_HandleTypeDef *hlptim);  /*!< poin
 #define __HAL_LPTIM_LPTIM2_EXTI_DISABLE_IT()           (EXTI->IMR2\
                                                         &= ~(LPTIM_EXTI_LINE_LPTIM2))
 
+
 /**
   * @brief  Enable the LPTIM2 EXTI line in event mode.
   * @retval None
@@ -642,6 +643,7 @@ typedef  void (*pLPTIM_CallbackTypeDef)(LPTIM_HandleTypeDef *hlptim);  /*!< poin
 #define __HAL_LPTIM_LPTIM3_EXTI_DISABLE_IT()           (EXTI->IMR2\
                                                         &= ~(LPTIM_EXTI_LINE_LPTIM3))
 
+
 /**
   * @brief  Enable the LPTIM3 EXTI line in event mode.
   * @retval None
@@ -740,9 +742,9 @@ HAL_StatusTypeDef HAL_LPTIM_Counter_Stop_IT(LPTIM_HandleTypeDef *hlptim);
   * @{
   */
 /* Reading operation functions ************************************************/
-uint32_t HAL_LPTIM_ReadCounter(const LPTIM_HandleTypeDef *hlptim);
-uint32_t HAL_LPTIM_ReadAutoReload(const LPTIM_HandleTypeDef *hlptim);
-uint32_t HAL_LPTIM_ReadCompare(const LPTIM_HandleTypeDef *hlptim);
+uint32_t HAL_LPTIM_ReadCounter(LPTIM_HandleTypeDef *hlptim);
+uint32_t HAL_LPTIM_ReadAutoReload(LPTIM_HandleTypeDef *hlptim);
+uint32_t HAL_LPTIM_ReadCompare(LPTIM_HandleTypeDef *hlptim);
 /**
   * @}
   */
@@ -873,13 +875,11 @@ HAL_LPTIM_StateTypeDef HAL_LPTIM_GetState(LPTIM_HandleTypeDef *hlptim);
 #define IS_LPTIM_COUNTER_SOURCE(__SOURCE__)     (((__SOURCE__) == LPTIM_COUNTERSOURCE_INTERNAL) || \
                                                  ((__SOURCE__) == LPTIM_COUNTERSOURCE_EXTERNAL))
 
-#define IS_LPTIM_AUTORELOAD(__AUTORELOAD__)     ((0x00000001UL <= (__AUTORELOAD__)) &&\
-                                                 ((__AUTORELOAD__) <= 0x0000FFFFUL))
+#define IS_LPTIM_AUTORELOAD(__AUTORELOAD__)     ((__AUTORELOAD__) <= 0x0000FFFFUL)
 
 #define IS_LPTIM_COMPARE(__COMPARE__)           ((__COMPARE__) <= 0x0000FFFFUL)
 
-#define IS_LPTIM_PERIOD(__PERIOD__)             ((0x00000001UL <= (__PERIOD__)) &&\
-                                                 ((__PERIOD__) <= 0x0000FFFFUL))
+#define IS_LPTIM_PERIOD(__PERIOD__)             ((__PERIOD__) <= 0x0000FFFFUL)
 
 #define IS_LPTIM_PULSE(__PULSE__)               ((__PULSE__) <= 0x0000FFFFUL)
 
@@ -934,3 +934,5 @@ void LPTIM_Disable(LPTIM_HandleTypeDef *hlptim);
 #endif
 
 #endif /* STM32L5xx_HAL_LPTIM_H */
+
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
