@@ -4,17 +4,7 @@
   * @author  MCD Application Team
   * @brief   HAL module driver.
   *          This is the common part of the HAL initialization
-  ******************************************************************************
-  * @attention
   *
-  * Copyright (c) 2019 STMicroelectronics.
-  * All rights reserved.
-  *
-  * This software is licensed under terms that can be found in the LICENSE file
-  * in the root directory of this software component.
-  * If no LICENSE file comes with this software, it is provided AS-IS.
-  *
-  ******************************************************************************
   @verbatim
   ==============================================================================
                      ##### How to use this driver #####
@@ -29,6 +19,17 @@
 
   @endverbatim
   ******************************************************************************
+  * @attention
+  *
+  * <h2><center>&copy; Copyright (c) 2019 STMicroelectronics. 
+  * All rights reserved.</center></h2>
+  *
+  * This software component is licensed by ST under BSD 3-Clause license,
+  * the "License"; You may not use this file except in compliance with the 
+  * License. You may obtain a copy of the License at:
+  *                        opensource.org/licenses/BSD-3-Clause
+  *
+  ******************************************************************************
   */
 
 /* Includes ------------------------------------------------------------------*/
@@ -52,20 +53,20 @@
   * @{
   */
 /**
-  * @brief STM32WBxx HAL Driver version number
+ * @brief STM32WBxx HAL Driver version number
    */
 #define __STM32WBxx_HAL_VERSION_MAIN   (0x01U) /*!< [31:24] main version */
-#define __STM32WBxx_HAL_VERSION_SUB1   (0x0EU) /*!< [23:16] sub1 version */
+#define __STM32WBxx_HAL_VERSION_SUB1   (0x08U) /*!< [23:16] sub1 version */
 #define __STM32WBxx_HAL_VERSION_SUB2   (0x00U) /*!< [15:8]  sub2 version */
 #define __STM32WBxx_HAL_VERSION_RC     (0x00U) /*!< [7:0]  release candidate */
 #define __STM32WBxx_HAL_VERSION         ((__STM32WBxx_HAL_VERSION_MAIN << 24U)\
-                                         |(__STM32WBxx_HAL_VERSION_SUB1 << 16U)\
-                                         |(__STM32WBxx_HAL_VERSION_SUB2 << 8U )\
-                                         |(__STM32WBxx_HAL_VERSION_RC))
+                                        |(__STM32WBxx_HAL_VERSION_SUB1 << 16U)\
+                                        |(__STM32WBxx_HAL_VERSION_SUB2 << 8U )\
+                                        |(__STM32WBxx_HAL_VERSION_RC))
 
 #if defined(VREFBUF)
 #define VREFBUF_TIMEOUT_VALUE     10U   /* 10 ms */
-#endif /* VREFBUF */
+#endif
 
 /**
   * @}
@@ -91,8 +92,8 @@ HAL_TickFreqTypeDef uwTickFreq = HAL_TICK_FREQ_DEFAULT;  /* 1KHz */
   */
 
 /** @addtogroup HAL_Exported_Functions_Group1
-  *  @brief    HAL Initialization and Configuration functions
-  *
+ *  @brief    HAL Initialization and Configuration functions
+ *
 @verbatim
  ===============================================================================
            ##### HAL Initialization and Configuration functions #####
@@ -148,11 +149,11 @@ HAL_StatusTypeDef HAL_Init(void)
   /* - Instruction cache enabled                             */
   /* - Data cache enabled                                    */
 #if (INSTRUCTION_CACHE_ENABLE == 0U)
-  __HAL_FLASH_INSTRUCTION_CACHE_DISABLE();
+   __HAL_FLASH_INSTRUCTION_CACHE_DISABLE();
 #endif /* INSTRUCTION_CACHE_ENABLE */
 
 #if (DATA_CACHE_ENABLE == 0U)
-  __HAL_FLASH_DATA_CACHE_DISABLE();
+   __HAL_FLASH_DATA_CACHE_DISABLE();
 #endif /* DATA_CACHE_ENABLE */
 
 #if (PREFETCH_ENABLE != 0U)
@@ -161,7 +162,7 @@ HAL_StatusTypeDef HAL_Init(void)
 
   /* Set Interrupt Group Priority */
   HAL_NVIC_SetPriorityGrouping(NVIC_PRIORITYGROUP_4);
-
+  
   /* Use SysTick as time base source and configure 1ms tick (default clock after Reset is MSI) */
   if (HAL_InitTick(TICK_INT_PRIORITY) != HAL_OK)
   {
@@ -193,7 +194,7 @@ HAL_StatusTypeDef HAL_DeInit(void)
 
   __HAL_RCC_APB3_FORCE_RESET();
   __HAL_RCC_APB3_RELEASE_RESET();
-
+  
   __HAL_RCC_AHB1_FORCE_RESET();
   __HAL_RCC_AHB1_RELEASE_RESET();
 
@@ -215,7 +216,7 @@ HAL_StatusTypeDef HAL_DeInit(void)
   * @retval None
   */
 __weak void HAL_MspInit(void)
-{
+{   
   /* NOTE : This function should not be modified, when the callback is needed,
             the HAL_MspInit could be implemented in the user file
    */
@@ -226,7 +227,7 @@ __weak void HAL_MspInit(void)
   * @retval None
   */
 __weak void HAL_MspDeInit(void)
-{
+{     
   /* NOTE : This function should not be modified, when the callback is needed,
             the HAL_MspDeInit could be implemented in the user file
    */
@@ -255,7 +256,7 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
   if ((uint32_t)uwTickFreq != 0U)
   {
     /*Configure the SysTick to have interrupt in 1ms time basis*/
-    if (HAL_SYSTICK_Config(HAL_RCC_GetHCLKFreq() / (1000U / (uint32_t)uwTickFreq)) == 0U)
+    if (HAL_SYSTICK_Config(HAL_RCC_GetHCLKFreq()/ (1000U / (uint32_t)uwTickFreq)) == 0U)
     {
       /* Configure the SysTick IRQ priority */
       if (TickPriority < (1UL << __NVIC_PRIO_BITS))
@@ -269,7 +270,7 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
       }
     }
     else
-    {
+    {  
       status = HAL_ERROR;
     }
   }
@@ -287,8 +288,8 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
   */
 
 /** @addtogroup HAL_Exported_Functions_Group2
-  *  @brief    HAL Control functions
-  *
+ *  @brief    HAL Control functions
+ *
 @verbatim
  ===============================================================================
                       ##### HAL Control functions #####
@@ -312,7 +313,7 @@ __weak HAL_StatusTypeDef HAL_InitTick(uint32_t TickPriority)
   *        used as application time base.
   * @note In the default implementation, this variable is incremented each 1ms
   *       in SysTick ISR.
-  * @note This function is declared as __weak to be overwritten in case of other
+ * @note This function is declared as __weak to be overwritten in case of other
   *      implementations in user file.
   * @retval None
   */
@@ -360,7 +361,7 @@ HAL_StatusTypeDef HAL_SetTickFreq(HAL_TickFreqTypeDef Freq)
     /* Update uwTickFreq global variable used by HAL_InitTick() */
     uwTickFreq = Freq;
 
-    /* Apply the new tick Freq */
+    /* Apply the new tick Freq  */
     status = HAL_InitTick(uwTickPrio);
 
     if (status != HAL_OK)
@@ -375,8 +376,7 @@ HAL_StatusTypeDef HAL_SetTickFreq(HAL_TickFreqTypeDef Freq)
 
 /**
   * @brief Return tick frequency.
-  * @retval Tick frequency.
-  *         Value of @ref HAL_TickFreqTypeDef.
+  * @retval tick period in Hz
   */
 HAL_TickFreqTypeDef HAL_GetTickFreq(void)
 {
@@ -384,8 +384,8 @@ HAL_TickFreqTypeDef HAL_GetTickFreq(void)
 }
 
 /**
-  * @brief This function provides minimum delay (in milliseconds) based
-  *        on variable incremented.
+  * @brief This function provides minimum delay (in milliseconds) based 
+  *        on variable incremented. 
   * @note In the default implementation , SysTick timer is the source of time base.
   *       It is used to generate interrupts at regular time intervals where uwTick
   *       is incremented.
@@ -394,22 +394,22 @@ HAL_TickFreqTypeDef HAL_GetTickFreq(void)
   * @param Delay  specifies the delay time length, in milliseconds.
   * @retval None
   */
-__weak void HAL_Delay(uint32_t Delay)
-{
-  uint32_t tickstart = HAL_GetTick();
-  uint32_t wait = Delay;
-
-  /* Add a freq to guarantee minimum wait */
-  if (wait < HAL_MAX_DELAY)
+  __weak void HAL_Delay(uint32_t Delay)
   {
-    wait += (uint32_t)(uwTickFreq);
+    uint32_t tickstart = HAL_GetTick();
+    uint32_t wait = Delay;
+  
+    /* Add a freq to guarantee minimum wait */
+    if (wait < HAL_MAX_DELAY)
+    {
+      wait += (uint32_t)(uwTickFreq);
+    }
+  
+    while ((HAL_GetTick() - tickstart) < wait)
+    {
+    }
   }
 
-  while ((HAL_GetTick() - tickstart) < wait)
-  {
-  }
-}
-
 
 /**
   * @brief Suspend Tick increment.
@@ -424,7 +424,7 @@ __weak void HAL_Delay(uint32_t Delay)
 __weak void HAL_SuspendTick(void)
 {
   /* Disable SysTick Interrupt */
-  CLEAR_BIT(SysTick->CTRL, SysTick_CTRL_TICKINT_Msk);
+  CLEAR_BIT(SysTick->CTRL,SysTick_CTRL_TICKINT_Msk);
 }
 
 /**
@@ -440,7 +440,7 @@ __weak void HAL_SuspendTick(void)
 __weak void HAL_ResumeTick(void)
 {
   /* Enable SysTick Interrupt */
-  SET_BIT(SysTick->CTRL, SysTick_CTRL_TICKINT_Msk);
+  SET_BIT(SysTick->CTRL,SysTick_CTRL_TICKINT_Msk);
 }
 
 /**
@@ -449,7 +449,7 @@ __weak void HAL_ResumeTick(void)
   */
 uint32_t HAL_GetHalVersion(void)
 {
-  return __STM32WBxx_HAL_VERSION;
+ return __STM32WBxx_HAL_VERSION;
 }
 
 /**
@@ -458,7 +458,7 @@ uint32_t HAL_GetHalVersion(void)
   */
 uint32_t HAL_GetREVID(void)
 {
-  return (LL_DBGMCU_GetRevisionID());
+   return(LL_DBGMCU_GetRevisionID());
 }
 
 /**
@@ -467,7 +467,7 @@ uint32_t HAL_GetREVID(void)
   */
 uint32_t HAL_GetDEVID(void)
 {
-  return (LL_DBGMCU_GetDeviceID());
+   return(LL_DBGMCU_GetDeviceID());
 }
 
 /**
@@ -476,7 +476,7 @@ uint32_t HAL_GetDEVID(void)
   */
 uint32_t HAL_GetUIDw0(void)
 {
-  return (READ_REG(*((uint32_t *)UID_BASE)));
+  return(READ_REG(*((uint32_t *)UID_BASE)));
 }
 
 /**
@@ -485,7 +485,7 @@ uint32_t HAL_GetUIDw0(void)
   */
 uint32_t HAL_GetUIDw1(void)
 {
-  return (READ_REG(*((uint32_t *)(UID_BASE + 4U))));
+  return(READ_REG(*((uint32_t *)(UID_BASE + 4U))));
 }
 
 /**
@@ -494,7 +494,7 @@ uint32_t HAL_GetUIDw1(void)
   */
 uint32_t HAL_GetUIDw2(void)
 {
-  return (READ_REG(*((uint32_t *)(UID_BASE + 8U))));
+  return(READ_REG(*((uint32_t *)(UID_BASE + 8U))));
 }
 
 /**
@@ -502,8 +502,8 @@ uint32_t HAL_GetUIDw2(void)
   */
 
 /** @addtogroup HAL_Exported_Functions_Group3
-  *  @brief    HAL Debug functions
-  *
+ *  @brief    HAL Debug functions
+ *
 @verbatim
  ===============================================================================
                       ##### HAL Debug functions #####
@@ -576,8 +576,8 @@ void HAL_DBGMCU_DisableDBGStandbyMode(void)
   */
 
 /** @defgroup HAL_Exported_Functions_Group4 HAL System Configuration functions
-  *  @brief    HAL System Configuration functions
-  *
+ *  @brief    HAL System Configuration functions
+ *
 @verbatim
  ===============================================================================
                  ##### HAL system configuration functions #####
@@ -634,9 +634,9 @@ uint32_t HAL_SYSCFG_IsEnabledSRAMFetch(void)
   * @brief Configure the internal voltage reference buffer voltage scale.
   * @param VoltageScaling  specifies the output voltage to achieve
   *          This parameter can be one of the following values:
-  *            @arg @ref SYSCFG_VREFBUF_VOLTAGE_SCALE0 : VREF_OUT1 around 2.048 V.
+  *            @arg @ref SYSCFG_VREFBUF_VOLTAGE_SCALE0 : VREF_OUT1 around 2.048 V. 
   *                                                This requires VDDA equal to or higher than 2.4 V.
-  *            @arg @ref SYSCFG_VREFBUF_VOLTAGE_SCALE1 : VREF_OUT1 around 2.5 V.
+  *            @arg @ref SYSCFG_VREFBUF_VOLTAGE_SCALE1 : VREF_OUT1 around 2.5 V. 
   *                                                This requires VDDA equal to or higher than 2.8 V.
   * @note   Retrieve the TrimmingValue from factory located at
   *         VREFBUF_SC0_CAL_ADDR or VREFBUF_SC1_CAL_ADDR addresses.
@@ -648,17 +648,17 @@ void HAL_SYSCFG_VREFBUF_VoltageScalingConfig(uint32_t VoltageScaling)
 
   /* Check the parameters */
   assert_param(IS_SYSCFG_VREFBUF_VOLTAGE_SCALE(VoltageScaling));
-
+  
   LL_VREFBUF_SetVoltageScaling(VoltageScaling);
 
   /* Restrieve Calibration data and store them into trimming field */
   if (VoltageScaling == SYSCFG_VREFBUF_VOLTAGE_SCALE0)
   {
-    TrimmingValue = ((uint32_t) * VREFBUF_SC0_CAL_ADDR) & 0x3FU;
+    TrimmingValue = ((uint32_t) *VREFBUF_SC0_CAL_ADDR) & 0x3FU;
   }
   else
   {
-    TrimmingValue = ((uint32_t) * VREFBUF_SC1_CAL_ADDR) & 0x3FU;
+    TrimmingValue = ((uint32_t) *VREFBUF_SC1_CAL_ADDR) & 0x3FU;
   }
   assert_param(IS_SYSCFG_VREFBUF_TRIMMING(TrimmingValue));
 
@@ -698,7 +698,7 @@ void HAL_SYSCFG_VREFBUF_TrimmingConfig(uint32_t TrimmingValue)
 {
   /* Check the parameters */
   assert_param(IS_SYSCFG_VREFBUF_TRIMMING(TrimmingValue));
-
+  
   LL_VREFBUF_SetTrimming(TrimmingValue);
 
 }
@@ -710,16 +710,16 @@ void HAL_SYSCFG_VREFBUF_TrimmingConfig(uint32_t TrimmingValue)
 HAL_StatusTypeDef HAL_SYSCFG_EnableVREFBUF(void)
 {
   uint32_t tickstart;
-
+  
   LL_VREFBUF_Enable();
-
+  
   /* Get Start Tick*/
   tickstart = HAL_GetTick();
 
   /* Wait for VRR bit  */
-  while (READ_BIT(VREFBUF->CSR, VREFBUF_CSR_VRR) == 0U)
+  while(READ_BIT(VREFBUF->CSR, VREFBUF_CSR_VRR) == 0U)
   {
-    if ((HAL_GetTick() - tickstart) > VREFBUF_TIMEOUT_VALUE)
+    if((HAL_GetTick() - tickstart) > VREFBUF_TIMEOUT_VALUE)
     {
       return HAL_TIMEOUT;
     }
@@ -850,3 +850,5 @@ uint32_t HAL_SYSCFG_IsEnabledSecurityAccess(uint32_t SecurityAccess)
 /**
   * @}
   */
+
+/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
