@@ -13,8 +13,6 @@
 #error "Include metal/sys.h instead of metal/generic/@PROJECT_MACHINE@/sys.h"
 #endif
 
-#include <metal/system/@PROJECT_SYSTEM@/xlnx_common/sys.h>
-
 #ifndef __METAL_GENERIC_MICROBLAZE_SYS__H__
 #define __METAL_GENERIC_MICROBLAZE_SYS__H__
 
@@ -26,10 +24,6 @@ extern "C" {
 
 #ifdef METAL_INTERNAL
 
-#ifndef XLNX_MAXIRQS
-#define XLNX_MAXIRQS 32
-#endif
-
 void metal_weak sys_irq_enable(unsigned int vector);
 
 void metal_weak sys_irq_disable(unsigned int vector);
