@@ -28,6 +28,10 @@ struct remote_resource_table {
 	unsigned int num;
 	unsigned int reserved[2];
 	unsigned int offset[NO_RESOURCE_ENTRIES];
+	/* rproc memory entry */
+	struct fw_rsc_rproc_mem rproc_mem;
+	/* firmware checksum */
+	struct fw_rsc_fw_chksum fw_chksum;
 	/* rpmsg vdev entry */
 	struct fw_rsc_vdev rpmsg_vdev;
 	struct fw_rsc_vdev_vring rpmsg_vring0;
